@@ -28,88 +28,9 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-###############################################################################
-## Paths and configuration                                                   ##
-###############################################################################
-
-# The following properties allow you to explicitly set xulrunner paths and
-# library names in the case that Miro guesses them wrong for your system.
-# When setting these, you must make sure that:
-#
-# 1. The gtkmozembed Python module is compiled against the same xulrunner
-#    that you're compiling AND running Miro against.
-#
-# 2. That you compile and run Miro with xulrunner 1.8 OR 1.9--you can't
-#    use both.
-
-
-# Location of the libxpcom.so file that's used for runtime.
-# This is used to set the LD_LIBRARY_PATH environment variable.
-#
-# It's possible that this path is already in your LD_LIBRARY_PATH in
-# which case you don't have to set it at all.
-#
-# Leave this set to None and Miro will attempt to guess at where it
-# is.  This sometimes works.  If it doesn't on your system, let us know
-# and we'll try to fix the guessing code.
-#
-# NOTE: Make sure this comes from the same xulrunner/firefox runtime that
-# Miro is compiled against.  If it's wrong, you'll likely see complaints
-# of missing symbols when you try to run Miro.
-#
-# Examples:
-# XPCOM_RUNTIME_PATH = "/usr/lib/firefox"
-# XPCOM_RUNTIME_PATH = "/usr/lib/xulrunner-1.9.0.1"
-XPCOM_RUNTIME_PATH = None
-
-# Location of xulrunner/firefox components for gtkmozembed.set_comp_path.
-# See documentation for set_comp_path here:
-# http://www.mozilla.org/unix/gtk-embedding.html
-#
-# Leave this set to None and Miro will attempt to guess at where it
-# is.  This sometimes works.  If it doesn't on your system, let us know
-# and we'll try to fix the guessing code.
-#
-# Examples:
-# MOZILLA_LIB_PATH = "/usr/lib/xulrunner-1.9.0.1"
-MOZILLA_LIB_PATH = None
-
-# The name of the library for the xpcom and gtkmozembed you want to compile
-# against on this system.  These strings are passed to pkg-config to get all
-# the information Miro needs to compile our browser widget.
-#
-# You should be able to do the following with the libraries you provide:
-#
-#    pkg-config --cflags --libs --define-variable=includetype=unstable \
-#        <xpcom-library> <gtkmozembed-library>
-#
-# and get back lots of exciting data.
-#
-# Set the XULRUNNER_19 flag to True if compiling against xulrunner 1.9 or
-# False if compiling against xulrunner 1.8 or some earlier version.
-#
-# Leave these three set to None and Miro will attempt to guess at values.
-# This sometimes works.  If it doesn't on your system, let us know and we'll
-# try to fix the guessing code.
-#
-# NOTE: If you set one of these, you should set all of them.
-#
-# Examples:
-# XPCOM_LIB = "libxul"
-# GTKMOZEMBED_LIB = "libxul"
-# XULRUNNER_19 = True
-#
-# XPCOM_LIB = "firefox-xpcom"
-# GTKMOZEMBED_LIB = "firefox-gtkmozembed"
-# XULRUNNER_19 = False
-XPCOM_LIB = None
-GTKMOZEMBED_LIB = None
-XULRUNNER_19 = None
-
-
-###############################################################################
-## End of configuration. No user-serviceable parts inside                    ##
-###############################################################################
+################################################################
+## No user-serviceable parts inside                           ##
+################################################################
 
 import sys
 
@@ -247,13 +168,13 @@ def get_command_output(cmd, warnOnStderr=True, warnOnReturnCode=True):
 
 def parse_pkg_config(command, components, options_dict = None):
     """Helper function to parse compiler/linker arguments from
-    pkg-config/mozilla-config and update include_dirs, library_dirs, etc.
+    pkg-config and update include_dirs, library_dirs, etc.
 
     We return a dict with the following keys, which match up with keyword
     arguments to the setup function: include_dirs, library_dirs, libraries,
     extra_compile_args.
 
-    Command is the command to run (pkg-config, mozilla-config, etc).
+    Command is the command to run (pkg-config, etc).
     Components is a string that lists the components to get options for.
 
     If options_dict is passed in, we add options to it, instead of starting
@@ -294,16 +215,9 @@ def package_exists(package_name):
     # pkg-config returns 0 if the package is present
     return subprocess.call(['pkg-config', '--exists', package_name]) == 0
 
-def generate_miro(xpcom_path):
-    # build a miro script that wraps the miro.real script with an LD_LIBRARY_PATH
-    # environment variable to pick up the xpcom we decided to use.
-    runtimelib = ""
-
+def generate_miro():
     f = open(os.path.join(platform_dir, "miro"), "w")
-    if xpcom_path:
-        runtimelib = "MOZILLA_FIVE_HOME=%s LD_LIBRARY_PATH=%s " % (xpcom_path, xpcom_path)
-
-    f.write( \
+    f.write(
 """#!/bin/sh
 # This file is generated by setup.py.
 DEBUG=0
@@ -327,127 +241,14 @@ then
         exit;
     fi
 
-    %(runtimelib)s$GDB -ex 'set breakpoint pending on' -ex 'run' --args $PYTHON ./miro.real --sync "$@"
+    $GDB -ex 'set breakpoint pending on' -ex 'run' --args $PYTHON ./miro.real --sync "$@"
 else
-    %(runtimelib)smiro.real "$@"
+    miro.real "$@"
 fi
-""" % { "runtimelib": runtimelib})
+""")
     f.close()
 
 
-#### MozillaBrowser Extension ####
-def get_mozilla_stuff():
-    if XPCOM_LIB and GTKMOZEMBED_LIB and XULRUNNER_19 != None:
-        print "\nUsing XPCOM_LIB, GTKMOZEMBED_LIB and XULRUNNER_19 values...."
-        xulrunner19 = XULRUNNER_19
-        xpcom_lib = XPCOM_LIB
-        gtkmozembed_lib = GTKMOZEMBED_LIB
-
-    else:
-        print "\nTrying to figure out xpcom_lib, gtkmozembed_lib, and xulrunner_19 values...."
-        xulrunner19 = False
-        if package_exists('libxul'):
-            xulrunner19 = True
-            xpcom_lib = 'libxul'
-            gtkmozembed_lib = 'libxul'
-
-        elif package_exists('xulrunner-xpcom'):
-            xpcom_lib = 'xulrunner-xpcom'
-            gtkmozembed_lib = 'xulrunner-gtkmozembed'
-
-        elif package_exists('seamonkey-xpcom'):
-            xpcom_lib = 'seamonkey-xpcom'
-            gtkmozembed_lib = 'seamonkey-gtkmozembed'
-
-        elif package_exists('mozilla-xpcom'):
-            xpcom_lib = 'mozilla-xpcom'
-            gtkmozembed_lib = 'mozilla-gtkmozembed'
-
-        elif package_exists('firefox-xpcom'):
-            xpcom_lib = 'firefox-xpcom'
-            gtkmozembed_lib = 'firefox-gtkmozembed'
-
-        else:
-            print "Can't find libxul, xulrunner-xpcom, seamonkey-xpcom, mozilla-xpcom or firefox-xpcom"
-            print "One of these is required."
-            sys.exit(1)
-
-    print "using xpcom_lib: ", repr(xpcom_lib)
-    print "using gtkmozembed_lib: ", repr(gtkmozembed_lib)
-    print "using xulrunner19: ", repr(xulrunner19)
-
-    # use the XPCOM_RUNTIME_PATH that's set if there's one that's set
-    if XPCOM_RUNTIME_PATH:
-        print "\nUsing XPCOM_RUNTIME_PATH value...."
-        xpcom_runtime_path = XPCOM_RUNTIME_PATH
-    else:
-        print "\nTrying to figure out xpcom_runtime_path value...."
-        xpcom_runtime_path = get_command_output("pkg-config --variable=libdir %s" % xpcom_lib).strip()
-    print "using xpcom_runtime_path: ", repr(xpcom_runtime_path)
-
-    mozilla_browser_options = parse_pkg_config("pkg-config",
-            "gtk+-2.0 glib-2.0 pygtk-2.0 --define-variable=includetype=unstable %s %s" % (gtkmozembed_lib, xpcom_lib))
-
-    if MOZILLA_LIB_PATH:
-        print "\nUsing MOZILLA_LIB_PATH value...."
-        mozilla_lib_path = MOZILLA_LIB_PATH
-    else:
-        print "\nTrying to figure out mozilla_lib_path value...."
-        mozilla_lib_path = parse_pkg_config('pkg-config', '%s' % gtkmozembed_lib)['library_dirs']
-        mozilla_lib_path = mozilla_lib_path[0]
-    print "using mozilla_lib_path: ", repr(mozilla_lib_path)
-
-    mozilla_runtime_path = parse_pkg_config('pkg-config', gtkmozembed_lib)['runtime_dirs']
-
-    # Find the base mozilla directory, and add the subdirs we need.
-    def allInDir(directory, subdirs):
-        for subdir in subdirs:
-            if not os.path.exists(os.path.join(directory, subdir)):
-                return False
-        return True
-
-    xpcom_includes = parse_pkg_config("pkg-config", xpcom_lib)
-
-    # xulrunner 1.9 has a different directory structure where all the headers
-    # are in the same directory and that's already in include_dirs.  so we don't
-    # need to do this.
-    if not xulrunner19:
-        mozIncludeBase = None
-        for dir in xpcom_includes['include_dirs']:
-            if allInDir(dir, ['dom', 'gfx', 'widget']):
-                # we can be pretty confident that dir is the mozilla/firefox/xulrunner
-                # base include directory
-                mozIncludeBase = dir
-                break
-
-        if mozIncludeBase is not None:
-            for subdir in ['dom', 'gfx', 'widget', 'commandhandler', 'uriloader',
-                           'webbrwsr', 'necko', 'windowwatcher', 'unstable',
-                           'embed_base']:
-                path = os.path.join(mozIncludeBase, subdir)
-                mozilla_browser_options['include_dirs'].append(path)
-
-    nsI = True
-    for dir in mozilla_browser_options['include_dirs']:
-        if os.path.exists(os.path.join(dir, "nsIServiceManagerUtils.h")):
-            nsI = True
-            break
-        if os.path.exists(os.path.join(dir, "nsServiceManagerUtils.h")):
-            nsI = False
-            break
-
-    if nsI:
-        mozilla_browser_options['extra_compile_args'].append('-DNS_I_SERVICE_MANAGER_UTILS=1')
-
-    # define PCF_USING_XULRUNNER19 if we're on xulrunner 1.9
-    if xulrunner19:
-        mozilla_browser_options['extra_compile_args'].append('-DPCF_USING_XULRUNNER19=1')
-
-    return mozilla_browser_options, mozilla_lib_path, xpcom_runtime_path, mozilla_runtime_path
-
-mozilla_browser_options, mozilla_lib_path, xpcom_runtime_path, mozilla_runtime_path = get_mozilla_stuff()
-
-
 #### Xlib Extension ####
 xlib_ext = \
     Extension("miro.plat.xlibhelper",
@@ -464,49 +265,6 @@ pygtkhacks_ext = \
             'pygobject-2.0 gtk+-2.0 glib-2.0 gthread-2.0')
     )
 
-mozprompt_ext = \
-    Extension("miro.plat.frontends.widgets.mozprompt",
-        [
-            os.path.join(platform_widgets_dir, 'mozprompt.pyx'),
-            os.path.join(platform_widgets_dir, 'PromptService.cc'),
-        ],
-        **mozilla_browser_options
-    )
-
-http_observer_options = mozilla_browser_options.copy()
-http_observer_options['include_dirs'].append(portable_xpcom_dir)
-
-httpobserver_ext = \
-    Extension("miro.plat.frontends.widgets.httpobserver",
-        [
-            os.path.join(platform_widgets_dir, 'httpobserver.pyx'),
-            os.path.join(portable_xpcom_dir, 'HttpObserver.cc'),
-        ],
-        **http_observer_options
-    )
-
-
-windowcreator_ext = \
-    Extension("miro.plat.frontends.widgets.windowcreator",
-        [
-            os.path.join(platform_widgets_dir, 'windowcreator.pyx'),
-            os.path.join(platform_widgets_dir, 'MiroWindowCreator.cc'),
-        ],
-        language="c++",
-        **mozilla_browser_options
-    )
-
-pluginsdir_ext = \
-    Extension("miro.plat.frontends.widgets.pluginsdir",
-        [
-            os.path.join(platform_widgets_dir, 'pluginsdir.pyx'),
-            os.path.join(platform_widgets_dir, 'MiroPluginsDir.cc'),
-        ],
-        language="c++",
-        **mozilla_browser_options
-    )
-
-
 #### Build the data_files list ####
 def listfiles(path):
     return [f for f in glob(os.path.join(path, '*')) if os.path.isfile(f)]
@@ -551,7 +309,7 @@ data_files += [
 # if we're not doing "python setup.py clean", then we can do a bunch of things
 # that have file-related side-effects
 if not "clean" in sys.argv:
-    generate_miro(xpcom_runtime_path)
+    generate_miro()
     # gzip the man page
     os.system ("gzip -9 < %s > %s" % (os.path.join(platform_dir, 'miro.1'), os.path.join(platform_dir, 'miro.1.gz')))
     # copy miro.1.gz to miro.real.1.gz so that lintian complains less
@@ -599,7 +357,7 @@ class install_data(distutils.command.install_data.install_data):
                              BUILD_MACHINE="%s@%s" % (getlogin(),
                                                       os.uname()[1]),
                              BUILD_TIME=str(time.time()),
-                             MOZILLA_LIB_PATH=mozilla_runtime_path[0])
+                             MOZILLA_LIB_PATH="")
         self.outfiles.append(dest)
 
         locale_dir = os.path.join (resource_dir, "locale")
@@ -711,10 +469,6 @@ class clean(Command):
 ext_modules = []
 ext_modules.append(xlib_ext)
 ext_modules.append(pygtkhacks_ext)
-ext_modules.append(mozprompt_ext)
-ext_modules.append(httpobserver_ext)
-ext_modules.append(windowcreator_ext)
-ext_modules.append(pluginsdir_ext)
 
 #### Run setup ####
 setup(name='miro',
