@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ from miro import downloader
 from miro import messages
 from miro import filetypes
 from miro import eventloop
+from miro import moviedata
 from miro import commandline
 from miro.frontends.widgets import menus
 from miro.frontends.widgets.application import Application
@@ -56,7 +57,7 @@ from miro.plat import growl
 from miro.plat import bundle
 from miro.plat import _growlImage
 from miro.plat import migrateappname
-from miro.plat.utils import ensureDownloadDaemonIsTerminated, filenameTypeToOSFilename, osFilenamesToFilenameTypes
+from miro.plat.utils import ensureDownloadDaemonIsTerminated, filename_type_to_os_filename, os_filename_to_filename_type
 from miro.plat.frontends.widgets import quicktime, osxmenus, sparkleupdater, threads
 from miro.plat.frontends.widgets.rect import Rect
 from miro.gtcache import gettext as _
@@ -81,13 +82,19 @@ class OSXApplication(Application):
         eventloop.connect('thread-did-start', self.endLoop)
         eventloop.connect('begin-loop', self.beginLoop)
         eventloop.connect('end-loop', self.endLoop)
+        moviedata.movie_data_updater.connect('begin-loop', self.beginLoop)
+        moviedata.movie_data_updater.connect('end-loop', self.endLoop)
         config.add_change_callback(self.on_pref_changed)
 
     def startup_ui(self):
         migrateappname.migrateVideos('Democracy', 'Miro')
         osxmenus.populate_menu()
         Application.startup_ui(self)
+        app.menu_manager.connect('enabled-changed', osxmenus.on_menu_change)
+        app.playback_manager.connect('did-start-playing', osxmenus.on_playback_change)
+        app.playback_manager.connect('did-stop', osxmenus.on_playback_change)
         quicktime.register_components()
+        quicktime.warm_up()
 
     # This callback should only be called once, after startup is done.
     # (see superclass implementation)
@@ -135,11 +142,11 @@ class OSXApplication(Application):
             NSWorkspace.sharedWorkspace().openURL_(NSURL.URLWithString_(url))
 
     def reveal_file(self, fn):
-        filename = filenameTypeToOSFilename(fn)
+        filename = filename_type_to_os_filename(fn)
         NSWorkspace.sharedWorkspace().selectFile_inFileViewerRootedAtPath_(filename, nil)
     
     def open_file(self, fn):
-        filename = filenameTypeToOSFilename(fn)
+        filename = filename_type_to_os_filename(fn)
         ws = NSWorkspace.sharedWorkspace()
         if utils.get_pyobjc_major_version() == 2:
             ok, externalApp, movieType = ws.getInfoForFile_application_type_(filename, None, None)
@@ -349,7 +356,7 @@ class AppController(NSObject):
         return NO
 
     def application_openFiles_(self, nsapp, filenames):
-        filenames = osFilenamesToFilenameTypes(filenames)
+        filenames = [os_filename_to_filename_type(f) for f in filenames]
         if self.startup_done:
             self.do_open_files(filenames)
         else:
@@ -397,7 +404,16 @@ class AppController(NSObject):
 
     def validateUserInterfaceItem_(self, menuitem):
         action = menuitem.representedObject()
-        group_names = menus.get_all_action_group_name(action)
+        item = menus.osx_menu_structure.get(action)
+
+        label = item.label
+        for state, actions in app.menu_manager.states.items():
+            if action in actions:
+                label = item.state_labels.get(state, item.label)
+                break
+        menuitem.setTitleWithMnemonic_(label.replace("_", "&"))
+
+        group_names = item.groups
         for group_name in group_names:
             if group_name in app.menu_manager.enabled_groups:
                 return True
