@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -321,7 +321,7 @@ class DetachedWindowHolder(Alignment):
 class SplitterDelegate(NSObject):
 
     def initWithSplitter_(self, splitter):
-        self = NSObject.init(self)
+        self = super(SplitterDelegate, self).init()
         self.splitter = splitter
         self.normalColor = NSColor.colorWithDeviceWhite_alpha_(64.0/255.0, 1.0)
         self.disabledColor = NSColor.colorWithDeviceWhite_alpha_(135.0/255.0, 1.0)
@@ -633,14 +633,14 @@ class Scroller(Bin):
         self.view.setHasVerticalScroller_(vertical)
         self.document_view = FlippedView.alloc().init()
         self.view.setDocumentView_(self.document_view)
-        clip_view = self.view.contentView()
-        self.clip_notifications = NotificationForwarder.create(clip_view)
-        clip_view.setPostsFrameChangedNotifications_(YES)
-        clip_view.setPostsBoundsChangedNotifications_(YES)
+        self.view.setAutohidesScrollers_(True)
 
     def set_has_borders(self, has_border):
         self.view.setBorderType_(NSBezelBorder)
 
+    def set_background_color(self, color):
+        self.view.setBackgroundColor_(self.make_color(color))
+
     def add(self, child):
         child.parent_is_scroller = True
         Bin.add(self, child)
@@ -649,35 +649,6 @@ class Scroller(Bin):
         child.parent_is_scroller = False
         Bin.remove(self)
 
-    def viewport_created(self):
-        Bin.viewport_created(self)
-        self.clip_notifications.connect(self._on_clip_view_frame_change,
-                'NSViewFrameDidChangeNotification')
-        self.clip_notifications.connect(self._on_clip_view_bounds_change,
-                'NSViewBoundsDidChangeNotification')
-
-    def remove_viewport(self):
-        Bin.remove_viewport(self)
-        self.clip_notifications.disconnect()
-
-    def _on_clip_view_frame_change(self, notification):
-        # If the clip view is larger than the document view (probably because
-        # we auto-hid a scrollbar), resize the document view to be at least as
-        # big as the clip view.
-        if not self.child:
-            return
-        clip_size = self.view.contentView().frame().size
-        document_size = self.document_view.frame().size
-        max_width = max(clip_size.width, document_size.width)
-        max_height = max(clip_size.height, document_size.height)
-        if (max_width != document_size.width or
-                max_height != document_size.height):
-            self.document_view.setFrameSize_(NSSize(max_width, max_height))
-
-    def _on_clip_view_bounds_change(self, notification):
-        if self.child:
-            self.child.viewport_scrolled()
-
     def calc_size_request(self):
         if self.child:
             width = height = 0
@@ -695,28 +666,24 @@ class Scroller(Bin):
             return 0, 0
 
     def place_children(self):
-        if self.child:
+        if self.child is not None:
             child_width, child_height = self.child.get_size_request()
-            child_width = max(child_width, self.view.contentSize().width)
-            child_height = max(child_height, self.view.contentSize().height)
-            self.document_view.setFrameSize_(NSSize(child_width,
-                child_height))
-            if isinstance(self.child, tableview.TableView):
+            child_width = max(child_width, self.view.contentView().frame().size.width)
+            frame = NSRect(NSPoint(0,0), NSSize(child_width, child_height))
+            if isinstance(self.child, tableview.TableView) and self.child.is_showing_headers():
                 # Hack to allow the content of a table view to scroll, but not
                 # the headers
-                self.child.place(self.document_view.frame(), self.view)
+                self.child.place(frame, self.document_view)
                 self.view.setDocumentView_(self.child.tableview)
-            elif self.child.CREATES_VIEW:
-                self.child.place(self.document_view.frame(), self.view)
-                self.view.setDocumentView_(self.child.view)
             else:
-                self.child.place(self.document_view.frame(), self.document_view)
+                self.child.place(frame, self.document_view)
+            self.document_view.setFrame_(frame)
             self.document_view.setNeedsDisplay_(YES)
         self.view.setNeedsDisplay_(YES)
 
 class ExpanderView(FlippedView):
     def init(self):
-        self = FlippedView.init(self)
+        self = super(ExpanderView, self).init()
         self.label_rect = None
         self.content_view = None
         self.button = NSButton.alloc().init()
