@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -36,9 +36,11 @@ from PyObjCTools import AppHelper
 from miro import app
 from miro import messages
 from miro.gtcache import gettext as _
+from miro.frontends.widgets.widgetconst import MAX_VOLUME
 from miro.plat import resources
 from miro.plat.frontends.widgets import threads
 from miro.plat.frontends.widgets import drawing
+from miro.plat.frontends.widgets import osxmenus
 
 ###############################################################################
 
@@ -177,6 +179,13 @@ class OverlayPalette (NSWindowController):
         if self.window().isVisible():
             self.adjustContent(videoWindow, True)
 
+    def showSubtitlesMenu_(self, sender):
+        menu = NSMenu.alloc().init()
+        menu.setAutoenablesItems_(NO)
+        subtitles_tracks = app.playback_manager.player.get_subtitle_tracks()
+        osxmenus.populate_subtitles_menu(menu, subtitles_tracks)
+        NSMenu.popUpContextMenu_withEvent_forView_(menu, NSApp().currentEvent(), self.window().contentView())
+    
     def getHorizontalPosition(self, videoWindow, width):
         parentFrame = videoWindow.frame()
         return parentFrame.origin.x + ((parentFrame.size.width - width) / 2.0)
@@ -229,7 +238,7 @@ class OverlayPalette (NSWindowController):
         if (not self.window().isVisible() and not self.revealing) or (self.window().isVisible() and self.hiding):
             self.update_(nil)
             if self.renderer.movie is not None:
-                self.volumeSlider.setFloatValue_(self.renderer.movie.volume())
+                self.set_volume(self.renderer.movie.volume())
 
             self.adjustPosition(videoWindow)
             self.adjustContent(videoWindow, False)
@@ -308,7 +317,7 @@ class OverlayPalette (NSWindowController):
         self.hiding = False
     
     def set_volume(self, volume):
-        self.volumeSlider.setFloatValue_(volume)
+        self.volumeSlider.setFloatValue_(volume / MAX_VOLUME)
     
     def keep_(self, sender):
         messages.KeepVideo(self.item_info.id).send_to_backend()
@@ -388,7 +397,7 @@ class OverlayPalette (NSWindowController):
             self.renderer.play()
 
     def volumeSliderWasDragged(self, slider):
-        volume = slider.floatValue()
+        volume = slider.floatValue() * MAX_VOLUME
         app.playback_manager.set_volume(volume)
         app.widgetapp.window.videobox.volume_slider.set_value(volume)
         self.resetAutoHiding()
@@ -578,7 +587,7 @@ class SkipSeekButtonCell (NSButtonCell):
         return newCell
     
     def initWithPrimaryAction_direction_delay_(self, action, direction, delay):
-        self = NSButtonCell.init(self)
+        self = super(SkipSeekButtonCell, self).init()
         self.primaryAction = action
         self.direction = direction
         self.seekTimer = nil
