@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ class ResizedImage(Image):
 
 class NSImageDisplay (NSView):
     def initWithImage_(self, image):
-        self = NSView.init(self)
+        self = super(NSImageDisplay, self).init()
         self.image = image
         return self
     def drawRect_(self, rect):
