@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@ just imports the widgets from their actual locations.
 """
 
 from miro.plat.frontends.widgets.const import *
-from miro.plat.frontends.widgets.control import TextEntry, SecureTextEntry, SearchTextEntry, VideoSearchTextEntry
+from miro.plat.frontends.widgets.control import TextEntry, SecureTextEntry, SearchTextEntry, VideoSearchTextEntry, MultilineTextEntry
 from miro.plat.frontends.widgets.control import Checkbox, Button, OptionMenu, RadioButtonGroup, RadioButton
 from miro.plat.frontends.widgets.customcontrol import CustomButton, ContinuousCustomButton, CustomSlider
 from miro.plat.frontends.widgets.drawing import DrawingContext, ImageSurface, Gradient
