@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@ from Foundation import *
 from objc import YES, NO, nil
 from PyObjCTools import AppHelper
 
-from miro import menubar
 from miro import signals
 from miro.frontends.widgets import widgetconst
 from miro.plat.frontends.widgets import osxmenus
@@ -52,7 +51,7 @@ alive_windows = set()
 
 class MiroWindow(NSWindow):
     def handle_keyDown(self, event):
-        key = event.characters()
+        key = event.charactersIgnoringModifiers()
         if len(key) != 1 or not key.isalpha():
             key = osxmenus.REVERSE_KEYS_MAP.get(key)
         mods = osxmenus.translate_event_modifiers(event)
@@ -317,16 +316,25 @@ class FileDialogBase(DialogBase):
         self._types = None
         self._filename = None
         self._directory = None
+        self._filter_on_run = True
 
     def run(self):
         self._panel.setAllowedFileTypes_(self._types)
         if self.sheet_parent is None:
-            response = self._panel.runModalForDirectory_file_(self._directory, self._filename, self._types)
+            if self._filter_on_run:
+                response = self._panel.runModalForDirectory_file_types_(self._directory, self._filename, self._types)
+            else:
+                response = self._panel.runModalForDirectory_file_(self._directory, self._filename)
         else:
             delegate = SheetDelegate.alloc().init()
-            self._panel.beginSheetForDirectory_file_modalForWindow_modalDelegate_didEndSelector_contextInfo_(
-                self._directory, self._filename,
-                self.sheet_parent.nswindow, delegate, 'sheetDidEnd:returnCode:contextInfo:', 0)
+            if self._filter_on_run:
+                self._panel.beginSheetForDirectory_file_types_modalForWindow_modalDelegate_didEndSelector_contextInfo_(
+                    self._directory, self._filename, self._types,
+                    self.sheet_parent.nswindow, delegate, 'sheetDidEnd:returnCode:contextInfo:', 0)
+            else:
+                self._panel.beginSheetForDirectory_file_modalForWindow_modalDelegate_didEndSelector_contextInfo_(
+                    self._directory, self._filename,
+                    self.sheet_parent.nswindow, delegate, 'sheetDidEnd:returnCode:contextInfo:', 0)
             response = NSApp().runModalForWindow_(self._panel)
             self._panel.orderOut_(nil)
         return response
@@ -336,7 +344,10 @@ class FileSaveDialog(FileDialogBase):
         FileDialogBase.__init__(self)
         self._title = title
         self._panel = NSSavePanel.savePanel()
+        self._panel.setCanChooseFiles_(YES)
+        self._panel.setCanChooseDirectories_(NO)
         self._filename = None
+        self._filter_on_run = False
 
     def set_filename(self, s):
         self._filename = filenameToUnicode(s)
@@ -362,6 +373,8 @@ class FileOpenDialog(FileDialogBase):
         FileDialogBase.__init__(self)
         self._title = title
         self._panel = NSOpenPanel.openPanel()
+        self._panel.setCanChooseFiles_(YES)
+        self._panel.setCanChooseDirectories_(NO)
         self._filenames = None
 
     def set_select_multiple(self, value):
@@ -496,6 +509,13 @@ class PreferencesWindow (Window):
         self.first_show = True
         self.nswindow.setShowsToolbarButton_(NO)
         self.nswindow.setReleasedWhenClosed_(NO)
+        self.app_notifications = NotificationForwarder.create(NSApp())
+        self.app_notifications.connect(self.on_app_quit, 
+            'NSApplicationWillTerminateNotification')
+
+    def destroy(self):
+        super(PreferencesWindow, self).destroy()
+        self.app_notifications.disconnect()
 
     def get_style_mask(self):
         return NSTitledWindowMask | NSClosableWindowMask | NSMiniaturizableWindowMask
@@ -537,3 +557,6 @@ class PreferencesWindow (Window):
             self.nswindow.center()
             self.first_show = False
         Window.show(self)
+
+    def on_app_quit(self, notification):
+        self.close()
