@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@ import datetime
 import subprocess
 
 from glob import glob
+from distutils.util import get_platform
 
 # =============================================================================
 # Find the top of the source tree and set the search path accordingly
@@ -47,7 +48,7 @@ from glob import glob
 BINARY_KIT_VERSION = open("binary_kit_version").read().strip()
 BKIT_DIR = os.path.join(os.getcwd(), "miro-binary-kit-osx-%s" % BINARY_KIT_VERSION)
 
-if not os.path.exists or not os.path.isdir(BKIT_DIR):
+if not os.path.exists(BKIT_DIR) or not os.path.isdir(BKIT_DIR):
     print "Binary kit %s is missing.  Run 'setup_binarykit.sh'." % BKIT_DIR
     sys.exit(1)
 
@@ -60,64 +61,33 @@ PLATFORM_DIR = os.path.join(ROOT_DIR, 'platform', 'osx')
 PLATFORM_PACKAGE_DIR = os.path.join(PLATFORM_DIR, 'plat')
 
 OS_INFO = os.uname()
-OS_VERSION = int(OS_INFO[2][0])
+OS_VERSION = int(OS_INFO[2].split('.')[0])
+PYTHON_VERSION = sys.version[0:3]
 
-if OS_VERSION == 9:
+if OS_VERSION < 9:
+    SANDBOX_DIR = "/usr/local"
+    PYTHON_ROOT = os.path.join("/", "Library", "Frameworks", "Python.framework", "Versions", "Current")
+    PYTHON_LIB = os.path.join(PYTHON_ROOT, "Python")
+    PYTHON_SITE_DIR = os.path.join(PYTHON_ROOT, 'lib', 'python%s' % PYTHON_VERSION, 'site-packages')
+else:
     SANDBOX_ROOT_DIR = os.path.normpath(os.path.normpath(os.path.join(ROOT_DIR, '..')))
     SANDBOX_DIR = os.path.join(SANDBOX_ROOT_DIR, 'sandbox')
-    PYTHON_ROOT = os.path.join(SANDBOX_DIR, "Library", "Frameworks", "Python.framework", "Versions", "Current")
+    PYTHON_ROOT = os.path.join("/", "System", "Library", "Frameworks", "Python.framework", "Versions", PYTHON_VERSION)
     PYTHON_LIB = os.path.join(PYTHON_ROOT, "Python")
-    PYTHON_VERSION = "2.5"
-    sys.path.insert(0, os.path.join(PYTHON_ROOT, 'lib', 'python2.5', 'site-packages'))
-else:
-    SANDBOX_DIR = "/usr/local"
-    PYTHON_LIB = os.path.join("/", "Library", "Frameworks", "Python.framework", "Versions", "Current", "Python")
-    PYTHON_VERSION = "2.4"
+    PYTHON_SITE_DIR = os.path.join(SANDBOX_DIR, 'lib', 'python%s' % PYTHON_VERSION, 'site-packages')
+    sys.path.insert(0, PYTHON_SITE_DIR)
 
 # =============================================================================
-# Look for the Boost library in various common places.
-# - we assume that both the library and the include files are installed in the
-#   same directory sub-hierarchy.
-# - we look for library and include directory in:
-#   - our local sandbox
-#   - the standard '/usr/local' tree
-#   - Darwinports' standard '/opt/local' tree
-#   - Fink's standard '/sw' tree
+# Drop out if the current binary kit isn't downloaded.
 # =============================================================================
 
-BOOST_LIB_DIR = None
-BOOST_INCLUDE_DIR = None
-BOOST_VERSION = None
-
-for searchDir in (SANDBOX_DIR, '/usr/local', '/opt/local', '/sw'):
-    libItems = glob(os.path.join(searchDir, 'lib/libboost_python*-1_35.*'))
-    incItems = glob(os.path.join(searchDir, 'include/boost-1_35/'))
-    if len(libItems) >= 1 and len(incItems) >= 1:
-        BOOST_LIB_DIR = os.path.dirname(libItems[0])
-        BOOST_INCLUDE_DIR = incItems[0]
-        match = re.search(r'libboost_python-(.*)\..*', libItems[0])
-        BOOST_VERSION = match.groups()[0]
-        break
-
-if BOOST_LIB_DIR is None or BOOST_INCLUDE_DIR is None:
-    print 'Boost library could not be found, interrupting build.'
+if not os.path.exists(BKIT_DIR):
+    print "Binary kit %s is not installed." % BKIT_DIR
+    if OS_VERSION < 9:
+        print "Run setup_sandbox_10.4.sh."
+    else:
+        print "Run setup_sandbox.sh."
     sys.exit(1)
-else:
-    print 'Boost library (version %s) found in %s' % (BOOST_VERSION, BOOST_LIB_DIR)
-
-# =============================================================================
-# We're going to explicitely pass these when linking our extensions to:
-# - avoid a linker error if we would specify the libraries using -L and -l
-#   flags since we also specify a isysroot.
-# - avoid the linker warnings which would occur if we would remove the 
-#   isysroot flag.
-# =============================================================================
-
-BOOST_PYTHON_LIB = os.path.join(SANDBOX_DIR, "lib", "libboost_python-%s.a" % BOOST_VERSION)
-BOOST_FILESYSTEM_LIB = os.path.join(SANDBOX_DIR, "lib", 'libboost_filesystem-%s.a' % BOOST_VERSION)
-BOOST_DATETIME_LIB = os.path.join(SANDBOX_DIR, "lib", 'libboost_date_time-%s.a' % BOOST_VERSION)
-BOOST_THREAD_LIB = os.path.join(SANDBOX_DIR, "lib", 'libboost_thread-%s.a' % BOOST_VERSION)
-BOOST_SYSTEM_LIB = os.path.join(SANDBOX_DIR, "lib", 'libboost_system-%s.a' % BOOST_VERSION)
 
 # =============================================================================
 # Only now may we import things from the local sandbox and our own tree
@@ -297,9 +267,7 @@ class MiroBuild (py2app):
         self.distribution.ext_modules.append(self.get_growl_ext())
         self.distribution.ext_modules.append(self.get_growl_image_ext())
         self.distribution.ext_modules.append(self.get_shading_ext())
-        self.distribution.ext_modules.append(self.get_sorts_ext())
         self.distribution.ext_modules.append(self.get_fasttypes_ext())
-        self.distribution.ext_modules.append(self.get_libtorrent_ext())
 
         self.distribution.packages = [
             'miro',
@@ -327,6 +295,7 @@ class MiroBuild (py2app):
             'qt_extractor.py'
         ]
         self.resources.extend(glob(os.path.join('Resources-Widgets', '*.png')))
+        self.resources.extend(glob(os.path.join('Resources-Widgets', 'warmup.mov')))
     
     def setup_options(self):
         self.bundleRoot = os.path.join(self.dist_dir, '%s.app/Contents' % self.config.get('shortAppName'))
@@ -337,7 +306,7 @@ class MiroBuild (py2app):
         
     def get_idletime_ext(self):
         idletime_src = glob(os.path.join(ROOT_DIR, 'platform', 'osx', 'modules', 'idletime.c'))
-        idletime_link_args = ['-framework', 'CoreFoundation']
+        idletime_link_args = ['-framework', 'CoreFoundation', '-framework', 'IOKit']
         return Extension("miro.plat.idletime", sources=idletime_src, extra_link_args=idletime_link_args)
     
     def get_keychain_ext(self):
@@ -347,7 +316,7 @@ class MiroBuild (py2app):
     
     def get_qtcomp_ext(self):
         qtcomp_src = glob(os.path.join(ROOT_DIR, 'platform', 'osx', 'modules', 'qtcomp.c'))
-        qtcomp_link_args = ['-framework', 'CoreFoundation', '-framework', 'Quicktime']
+        qtcomp_link_args = ['-framework', 'CoreFoundation', '-framework', 'CoreServices', '-framework', 'QuickTime']
         return Extension("miro.plat.qtcomp", sources=qtcomp_src, extra_link_args=qtcomp_link_args)
     
     def get_growl_ext(self):
@@ -365,61 +334,9 @@ class MiroBuild (py2app):
         shading_link_args = ['-framework', 'ApplicationServices']
         return Extension("miro.plat.shading", sources=shading_src, extra_link_args=shading_link_args)
     
-    def get_sorts_ext(self):
-        sorts_src = glob(os.path.join(ROOT_DIR, 'portable', 'sorts.pyx'))
-        return Extension("miro.sorts", sources=sorts_src)
-    
     def get_fasttypes_ext(self):
-        fasttypes_src = glob(os.path.join(ROOT_DIR, 'portable', 'fasttypes.cpp'))
-        fasttypes_inc_dirs = [BOOST_INCLUDE_DIR]
-        fasttypes_extras = [PYTHON_LIB, BOOST_PYTHON_LIB]
-        return Extension("miro.fasttypes", sources=fasttypes_src, 
-                                      include_dirs=fasttypes_inc_dirs, 
-                                      extra_objects=fasttypes_extras)
-    
-    def get_libtorrent_ext(self):
-        def libtorrent_sources_iterator():
-            for root,dirs,files in os.walk(os.path.join(PORTABLE_DIR, 'libtorrent')):
-                if '.svn' in dirs:
-                    dirs.remove('.svn')
-                for file in files:
-                    if file.endswith('.cpp') or file.endswith('.c'):
-                        yield os.path.join(root,file)
-
-        libtorrent_src = list(libtorrent_sources_iterator())
-        if os.path.exists(os.path.join(PORTABLE_DIR, 'libtorrent/src/file_win.cpp')):
-            libtorrent_src.remove(os.path.join(PORTABLE_DIR, 'libtorrent/src/file_win.cpp'))
-        libtorrent_inc_dirs = [BOOST_INCLUDE_DIR,
-                               os.path.join(PORTABLE_DIR, 'libtorrent', 'include'),
-                               os.path.join(PORTABLE_DIR, 'libtorrent', 'include', 'libtorrent')]
-        libtorrent_lib_dirs = [BOOST_LIB_DIR]
-        libtorrent_libs = ['z', 
-                           'pthread', 
-                           'ssl']
-
-        libtorrent_extras = [PYTHON_LIB,
-                             BOOST_PYTHON_LIB,
-                             BOOST_FILESYSTEM_LIB,
-                             BOOST_DATETIME_LIB,
-                             BOOST_THREAD_LIB,
-                             BOOST_SYSTEM_LIB]
-
-        libtorrent_compil_args = ["-Wno-missing-braces",
-                                  "-D_FILE_OFFSET_BITS=64",
-                                  "-DHAVE___INCLUDE_LIBTORRENT_ASIO_HPP=1",
-                                  "-DHAVE___INCLUDE_LIBTORRENT_ASIO_SSL_STREAM_HPP=1",
-                                  "-DHAVE___INCLUDE_LIBTORRENT_ASIO_IP_TCP_HPP=1",
-                                  "-DHAVE_PTHREAD=1", 
-                                  "-DTORRENT_USE_OPENSSL=1", 
-                                  "-DHAVE_SSL=1",
-                                  "-DNDEBUG",
-                                  "-O2"]
-
-        return Extension("miro.libtorrent", sources=libtorrent_src, 
-                                       include_dirs=libtorrent_inc_dirs,
-                                       libraries=libtorrent_libs, 
-                                       extra_objects=libtorrent_extras,
-                                       extra_compile_args=libtorrent_compil_args)
+        return Extension("miro.fasttypes", 
+                [os.path.join(PORTABLE_DIR, 'fasttypes.c')])
     
     def fillTemplate(self, templatepath, outpath, **vars):
         s = open(templatepath, 'rt').read()
@@ -432,6 +349,7 @@ class MiroBuild (py2app):
         print "Building %s v%s (%s)" % (self.config.get('longAppName'), self.config.get('appVersion'), self.config.get('appRevision'))
         
         self.setup_info_plist()
+        self.copy_libtorrent_module()
 
         py2app.run(self)
         
@@ -443,6 +361,10 @@ class MiroBuild (py2app):
         self.copy_localization_files()
         if self.theme is not None:
             self.copy_theme_files()
+        if not self.alias:
+            self.relocate_python_executable()
+            if OS_VERSION >= 9:
+                self.fix_install_names()
         
         self.clean_up_incomplete_lproj()
         self.clean_up_unwanted_data()
@@ -468,8 +390,64 @@ class MiroBuild (py2app):
         infoPlist['CFBundleAllowMixedLocalizations'] = True
         infoPlist['CFBundleLocalizations'] = self.get_localizations_list()
         
+        if not self.alias:
+            infoPlist['PyExecutableName'] = os.path.join("@executable_path", "..", "Frameworks", "Python.framework", "Versions", PYTHON_VERSION, "bin", "python")
+        
         self.plist = infoPlist
 
+    def copy_libtorrent_module(self):
+        print 'Copying the libtorrent module to application bundle'
+        src = os.path.join(PYTHON_SITE_DIR, 'libtorrent.so')
+        plat = get_platform()
+        dst_root = os.path.join('build', 'bdist.%s' % plat , 'lib.%s-%s' % (plat, PYTHON_VERSION))
+        if not os.path.exists(dst_root):
+            os.makedirs(dst_root)
+        dst = os.path.join(dst_root, 'libtorrent.so')
+        shutil.copy(src, dst)
+
+    def _get_app_root(self):
+        dist_app = os.path.join("dist", "Miro.app")
+        if os.path.exists(dist_app):
+            return dist_app
+        return "Miro.app"
+
+    def relocate_python_executable(self):
+        # In certain unknown circumstances, Mac OS will launch the embedded
+        # python executable instead of the Miro executable when the application
+        # is double clicked in the Finder, and since OS X LaunchServices pass
+        # a -psn_X_Y parameter representing the process serial number which
+        # python does not understand, bad things happen, as described in #13120.
+        # There is currently zero clue as to why this happens, but the workaround
+        # is simply to move the python executable to another location in the 
+        # application bundle, which prevents OS X to pick it as the main executable.
+        # (This also requires to add the PyExecutableName entry to the Info.plist, 
+        # which is done in setup_info_plist above).
+        
+        print "Relocating python executable"
+        app_root = self._get_app_root()
+        source = os.path.join(app_root, "Contents", "MacOS", "python")
+        target = os.path.join(app_root, "Contents", "Frameworks", "Python.framework", "Versions", PYTHON_VERSION, "bin")
+        if not os.path.exists(target):
+            os.mkdir(target)
+        shutil.move(source, target)
+
+        # Note that we obviously also need to update the executable install name.
+        
+        py_exe = os.path.join(target, "python")
+        old_install_name = os.path.join("@executable_path", "..", "Frameworks", "Python.framework", "Versions", PYTHON_VERSION, "Python")
+        new_install_name = os.path.join("@executable_path", "..", "Python")
+        os.system('install_name_tool -change %s %s %s' % (old_install_name, new_install_name, py_exe))
+
+    def fix_install_names(self):
+        py_install_name = os.path.join("@executable_path", "..", "Frameworks", "Python.framework", "Versions", PYTHON_VERSION, "Python")
+        app_root = self._get_app_root()
+
+        fasttypes_mod = os.path.join(app_root, "Contents", "Resources", "lib", "python%s" % PYTHON_VERSION, "lib-dynload", "miro", "fasttypes.so")
+        os.system('install_name_tool -change %s %s %s' % (PYTHON_LIB, py_install_name, fasttypes_mod))
+
+        libtorrent_so = os.path.join(app_root, "Contents", "Resources", "lib", "python%s" % PYTHON_VERSION, "lib-dynload", "libtorrent.so")
+        os.system('install_name_tool -change %s %s %s' % (PYTHON_LIB, py_install_name, libtorrent_so))
+
     def fix_frameworks_alias(self):
         # Py2App seems to have a bug where alias builds would get 
         # incorrect symlinks to frameworks, so create them manually. 
@@ -482,7 +460,7 @@ class MiroBuild (py2app):
                     os.symlink(os.path.dirname(dest), fmwk)
 
     def copy_quicktime_components(self):
-        print 'Copying Quicktime components to application bundle'
+        print 'Copying QuickTime components to application bundle'
         extract_binaries('qtcomponents', self.cmpntRoot, self.force_update)
 
     def copy_portable_resources(self):
