@@ -28,7 +28,6 @@
 
 """Startup the Main Miro process."""
 
-
 def startup():
     theme = None
     # Should have code to figure out the theme.
@@ -41,6 +40,9 @@ def startup():
         return
     pipe_server.start_process()
 
+    from miro.plat import miro_urlparse
+    miro_urlparse.apply_monkey_patch()
+
     from miro.plat import prelogger
     prelogger.install()
 
