@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -43,6 +43,10 @@ from time import sleep, time
 SEM_FAILCRITICALERRORS = 0x0001
 SEM_NOGPFAULTERRORBOX = 0x0002
 
+VLC_PLAYING = 3
+VLC_ENDED = 6
+VLC_ERROR = 7
+
 # load the DLL
 libvlc = ctypes.cdll.libvlc
 # set up the function signatures
@@ -91,21 +95,39 @@ def wait_for_play(media_player):
         state = libvlc.libvlc_media_player_get_state(media_player, 
                                                      byref(exception))
         check_exception()
-        if state in (3, 6, 7):
+        if state in (VLC_PLAYING, VLC_ENDED, VLC_ERROR):
             # Break on the PLAYING, ENDED or ERROR states
-            break
+            return state
         else:
             sleep(0.1)
 
+def get_type(media_player):
+    video_tracks = libvlc.libvlc_video_get_track_count(media_player, 
+            byref(exception))
+    try:
+        check_exception()
+    except VLCError:
+        video_tracks = 0
+    audio_tracks = libvlc.libvlc_audio_get_track_count(media_player,
+            byref(exception))
+    try:
+        check_exception()
+    except VLCError:
+        audio_tracks = 0
+
+    if video_tracks > 0:
+        return 'video'
+    elif audio_tracks > 0:
+        return 'audio'
+    else:
+        return 'other'
+
 def make_snapshot(video_path, thumbnail_path):
     if os.path.exists(thumbnail_path):
         os.remove(thumbnail_path)
 
     if isinstance(video_path, unicode):
         video_path = video_path.encode("utf-8")
-    video_path = urllib.quote(video_path)
-
-    mrl = 'file:///%s' % video_path
 
     vlc = init_vlc( "vlc", "--noaudio", 
             '--vout', 'dummy', 
@@ -117,7 +139,7 @@ def make_snapshot(video_path, thumbnail_path):
                                                   byref(exception))
     check_exception()
     media = libvlc.libvlc_media_new(vlc, 
-                                    ctypes.c_char_p(mrl),
+                                    ctypes.c_char_p(video_path),
                                     byref(exception))
     check_exception()
 
@@ -129,11 +151,17 @@ def make_snapshot(video_path, thumbnail_path):
                                     byref(exception))
     check_exception()
 
-    wait_for_play(media_player)
+    state = wait_for_play(media_player)
+    if state == VLC_ERROR:
+        print "Miro-Try-Again: True"
+        return
+    
     length = libvlc.libvlc_media_player_get_length(media_player, 
                                                    byref(exception))
     check_exception()
 
+    media_type = get_type(media_player)
+
     libvlc.libvlc_media_player_set_position(media_player, 
                                             ctypes.c_float(0.5),
                                             byref(exception))
@@ -141,15 +169,27 @@ def make_snapshot(video_path, thumbnail_path):
 
     # allow a little time for VLC to seek
     sleep(0.5)
-    libvlc.libvlc_video_take_snapshot(media_player, 
-                                      ctypes.c_char_p(thumbnail_path),
-                                      ctypes.c_int(0), 
-                                      ctypes.c_int(0),
-                                      byref(exception))
-    check_exception()
 
-    # allow a little time for VLC to take the snapshot
-    sleep(0.5)
+    # if it's a video, take a snapshot
+    if media_type == "video":
+        libvlc.libvlc_video_take_snapshot(media_player, 
+                                          ctypes.c_char_p(thumbnail_path),
+                                          ctypes.c_int(0), 
+                                          ctypes.c_int(0),
+                                          byref(exception))
+        check_exception()
+
+        # allow a little time for VLC to take the snapshot
+        sleep(0.5)
+
+    # if the length didn't work out before, we try it again
+    # FIXME - we can probably remove this when we switch to
+    # event handling in wait_for_play.
+    if length <= 0:
+        length = libvlc.libvlc_media_player_get_length(media_player, 
+                                                       byref(exception))
+        check_exception()
+
     libvlc.libvlc_media_player_stop(media_player, byref(exception))
     check_exception()
 
@@ -165,16 +205,17 @@ def make_snapshot(video_path, thumbnail_path):
         print "Miro-Movie-Data-Thumbnail: Success"
     else:
         print "Miro-Movie-Data-Thumbnail: Failure"
+    print "Miro-Movie-Data-Type: %s" % media_type
 
 if __name__ == '__main__':
-    if len(sys.argv) < 2:
+    if len(sys.argv) < 3:
         print "moviedata_util <video_path> <thumbnail_path>"
         sys.exit(0)
 
     try:
         # disable annoying windows popup
         ctypes.windll.kernel32.SetErrorMode(SEM_NOGPFAULTERRORBOX | 
-                SEM_FAILCRITICALERRORS)
+                                            SEM_FAILCRITICALERRORS)
         make_snapshot(sys.argv[1], sys.argv[2])
     except Exception, e:
         import traceback
