@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -148,6 +148,7 @@ class WindowsApplication(Application):
             self.quit()
 
     def quit_ui(self):
+        app.video_renderer.shutdown()
         for widget in persistentwindow.get_widgets():
             widget.destroy()
         if hasattr(self, "trayicon"):
@@ -185,7 +186,7 @@ class WindowsApplication(Application):
             webbrowser.get("windows-default").open_new(url)
         except:
             logging.warn("Error opening URL: %r\n%s", url,
-                    traceback.format_ext())
+                    traceback.format_exc())
             recommendURL = config.get(prefs.RECOMMEND_URL)
 
             if url.startswith(config.get(prefs.VIDEOBOMB_URL)):
