@@ -1,7 +1,7 @@
 #!/bin/sh
 
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,4 +30,4 @@
 
 setup_binarykit.sh
 python setup.py bdist_miro
-dist/Miro.exe
+cd dist && Miro.exe
