@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,25 +26,29 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-from miro import item as itemmod
-from miro import feed as feedmod
+from miro import models
 from miro import config
 from miro import prefs
 from miro import eventloop
 from datetime import datetime
-from miro.fasttypes import SortedList
 
 def pending_sort(a, b):
-    if a[1] < b[1]:
-        return True
-    if a[1] > b[1]:
-        return False
-    return a[2] < b[2]
+    return cmp((a[1], a[2]), (b[1], b[2]))
+
+def _key_for_feed(feed):
+    """Get the key to use for feed_pending_count and
+    feed_running_count dicts.  Normally this is the feed URL, but
+    the search downloads feed gets combined with the search feed
+    (ss #11778)
+    """
+    if feed.origURL == u'dtv:searchDownloads':
+        return u"dtv:search"
+
+    return feed.origURL
 
 class Downloader:
     def __init__(self, is_auto):
         self.dc = None
-        self.inDownloads = False
         self.paused = False
         self.running_count = 0
         self.pending_count = 0
@@ -53,12 +57,12 @@ class Downloader:
         self.feed_time = {}
         self.is_auto = is_auto
         if is_auto:
-            pending_items = itemmod.Item.auto_pending_view()
-            running_items = itemmod.Item.auto_downloads_view()
+            pending_items = models.Item.auto_pending_view()
+            running_items = models.Item.auto_downloads_view()
             self.MAX = config.get(prefs.DOWNLOADS_TARGET)
         else:
-            pending_items = itemmod.Item.manual_pending_view()
-            running_items = itemmod.Item.manual_downloads_view()
+            pending_items = models.Item.manual_pending_view()
+            running_items = models.Item.manual_downloads_view()
             self.MAX = config.get(prefs.MAX_MANUAL_DOWNLOADS)
 
         for item in pending_items:
@@ -77,7 +81,7 @@ class Downloader:
         if is_auto:
             self.new_count = 0
             self.feed_new_count = {}
-            new_items = itemmod.Item.unwatched_downloaded_items()
+            new_items = models.Item.unwatched_downloaded_items()
             for item in new_items:
                 self.new_on_add(None, item)
             self.new_items_tracker = new_items.make_tracker()
@@ -97,11 +101,13 @@ class Downloader:
         if self.paused:
             return
         last_count = 0
-        while self.running_count < self.MAX and self.pending_count > 0 and self.pending_count != last_count:
+        while (self.running_count < self.MAX
+               and self.pending_count > 0
+               and self.pending_count != last_count):
             last_count = self.pending_count
-            sorted = SortedList(pending_sort)
-            for feed in feedmod.Feed.make_view():
-                key = self._key_for_feed(feed)
+            candidate_feeds = []
+            for feed in models.Feed.make_view():
+                key = _key_for_feed(feed)
                 if self.is_auto:
                     max_new = feed.get_max_new()
                     if max_new != "unlimited":
@@ -112,8 +118,12 @@ class Downloader:
                             continue
                 if self.feed_pending_count.get(key, 0) <= 0:
                     continue
-                sorted.append((feed, self.feed_running_count.get(key, 0), self.feed_time.get(feed, datetime.min)))
-            for feed, count, time in sorted:
+                candidate_feeds.append((feed,
+                                        self.feed_running_count.get(key, 0),
+                                        self.feed_time.get(feed, datetime.min)))
+            candidate_feeds.sort(pending_sort)
+
+            for feed, count, dummy in candidate_feeds:
                 if self.is_auto:
                     feed.startAutoDownload()
                 else:
@@ -126,53 +136,44 @@ class Downloader:
     def start_downloads(self):
         if self.dc or self.paused:
             return
-        self.dc = eventloop.addIdle(self.start_downloads_idle, "Start Downloads")
-
-    def _key_for_feed(self, feed):
-        """Get the key to use for feed_pending_count and feed_running_count
-        dicts.  Normally this is the feed URL, but the search downloads feed
-        gets combined with the search feed (ss #11778)
-        """
-        if feed.origURL == u'dtv:searchDownloads':
-            return u"dtv:search"
-        else:
-            return feed.origURL
+        self.dc = eventloop.addIdle(self.start_downloads_idle,
+                                    "Start Downloads")
 
     def pending_on_add(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.pending_count = self.pending_count + 1
         self.feed_pending_count[key] = self.feed_pending_count.get(key, 0) + 1
         self.start_downloads()
-    
+
     def pending_on_remove(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.pending_count = self.pending_count - 1
         self.feed_pending_count[key] = self.feed_pending_count.get(key, 0) - 1
-    
+
     def running_on_add(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.running_count = self.running_count + 1
         self.feed_running_count[key] = self.feed_running_count.get(key, 0) + 1
-    
+
     def running_on_remove(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.running_count = self.running_count - 1
         self.feed_running_count[key] = self.feed_running_count.get(key, 0) - 1
         self.start_downloads()
-    
+
     def new_on_add(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.new_count = self.new_count + 1
         self.feed_new_count[key] = self.feed_new_count.get(key, 0) + 1
-    
+
     def new_on_remove(self, tracker, obj):
         feed = obj.get_feed()
-        key = self._key_for_feed(feed)
+        key = _key_for_feed(feed)
         self.new_count = self.new_count - 1
         self.feed_new_count[key] = self.feed_new_count.get(key, 0) - 1
         self.start_downloads()
@@ -186,27 +187,23 @@ class Downloader:
     def resume(self):
         if self.paused:
             self.paused = False
-            eventloop.addTimeout(5, self.start_downloads, "delayed start downloads")
+            eventloop.addTimeout(5, self.start_downloads,
+                                 "delayed start downloads")
 
-# These are both Downloader instances.
-manual_downloader = None
-auto_downloader = None
-autodlers_started = False
-auto_resume_after_start = False
+# these are both Downloader instances
+MANUAL_DOWNLOADER = None
+AUTO_DOWNLOADER = None
 
 def start_downloader():
-    global manual_downloader
-    global auto_downloader
-    global autodlers_started
-    global auto_resume_after_start
-    manual_downloader = Downloader(False)
-    auto_downloader = Downloader(True)
-    autodlers_started = True
+    global MANUAL_DOWNLOADER
+    global AUTO_DOWNLOADER
+    MANUAL_DOWNLOADER = Downloader(False)
+    AUTO_DOWNLOADER = Downloader(True)
 
 def _update_prefs(key, value):
     if key == prefs.DOWNLOADS_TARGET.key:
-        auto_downloader.update_max_downloads()
+        AUTO_DOWNLOADER.update_max_downloads()
     elif key == prefs.MAX_MANUAL_DOWNLOADS.key:
-        manual_downloader.update_max_downloads()
+        MANUAL_DOWNLOADER.update_max_downloads()
 
 config.add_change_callback(_update_prefs)
