@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,6 @@ from miro.appconfig import AppConfig
 from miro import app
 from miro import prefs
 from miro.plat import config as platformcfg
-import urllib
 import logging
 
 _data = None
@@ -45,12 +44,12 @@ _callbacks = set()
 def add_change_callback(callback):
     """Attaches change notification callback functions.
 
-    Callback functions should have a signature like 
+    Callback functions should have a signature like
     ``callback_function: key * value -> None``.  Example::
 
         def callback_function(key, value):
             if key == prefs.PRESERVE_X_GB_FREE:
-               blah blah blah
+                blah blah blah
     """
     _callbacks.add(callback)
 
@@ -60,9 +59,6 @@ def remove_change_callback(callback):
     _callbacks.discard(callback)
 
 def load(theme=None):
-    """The theme parameter is a horrible hack to load the theme before we
-    can import other modules.  pybridge makes the extra, early call
-    """
     global _data
     _lock.acquire()
     try:
@@ -87,31 +83,29 @@ def save():
     finally:
         _lock.release()
 
-def get(descriptor, useThemeData=True):
+def get(descriptor, use_theme_data=True):
     _lock.acquire()
     try:
         _check_validity()
 
         if _data is not None and descriptor.key in _data:
             value = _data[descriptor.key]
-            if descriptor.possible_values is not None and not value in descriptor.possible_values:
-                logging.warn('Incorrect preference value %s for key %s, using failsafe: %s' % (value, descriptor.key, descriptor.failsafe_value))
+            if ((descriptor.possible_values is not None
+                 and not value in descriptor.possible_values)):
+                logging.warn('bad preference value %s for key %s.  using failsafe: %s',
+                             value, descriptor.key, descriptor.failsafe_value)
                 return descriptor.failsafe_value
             else:
                 return value
         elif descriptor.platformSpecific:
             return platformcfg.get(descriptor)
-        if app.configfile.contains(descriptor.key, useThemeData):
-            return app.configfile.get(descriptor.key, useThemeData)
+        if app.configfile.contains(descriptor.key, use_theme_data):
+            return app.configfile.get(descriptor.key, use_theme_data)
         else:
             return descriptor.default
     finally:
         _lock.release()
 
-def get_list(descriptor):
-    # FIXME - this doesn't look used anywhere
-    return [urllib.unquote(i) for i in get(descriptor).split(",") if i]
-
 def set(descriptor, value):
     _lock.acquire()
     logging.debug("Setting %s to %s", descriptor.key, value)
@@ -123,10 +117,6 @@ def set(descriptor, value):
     finally:
         _lock.release()
 
-def set_list(descriptor, value):
-    # FIXME - this doesn't look used anywhere
-    set(descriptor, ','.join ([urllib.quote(i) for i in value]))
-
 def _check_validity():
     if _data == None:
         load()
@@ -134,4 +124,5 @@ def _check_validity():
 def _notify_listeners(key, value):
     from miro import eventloop
     for callback in _callbacks:
-        eventloop.addIdle(callback, 'config callback: %s' % callback, args=(key, value))
+        eventloop.addIdle(callback, 'config callback: %s' % callback,
+                          args=(key, value))
