@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -60,10 +60,10 @@ def launch():
 
     override_modules()
 
-    from miro.plat.utils import setup_logging, initializeLocale
+    from miro.plat.utils import setup_logging, initialize_locale
     setup_logging(inDownloader=True)
     util.setup_logging()
-    initializeLocale()
+    initialize_locale()
 
     if os.environ.get('DEMOCRACY_DOWNLOADER_FIRST_LAUNCH') != '1':
         logging.info ("*** Starting new downloader log ***")
