@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 
 """``miro.eventloop`` -- Event loop handler.
 
-This module handles the democracy event loop which is responsible for
+This module handles the miro event loop which is responsible for
 network requests and scheduling.
 
 TODO: handle user setting clock back
@@ -58,9 +58,9 @@ class DelayedCall(object):
         self.canceled = False
 
     def _unlink(self):
-        """Removes the references that this object has to the outside world,
-        this eases the GC's work in finding cycles and fixes some memory leaks
-        on windows.
+        """Removes the references that this object has to the outside
+        world, this eases the GC's work in finding cycles and fixes
+        some memory leaks on windows.
         """
         self.function = self.args = self.kwargs = None
 
@@ -69,10 +69,12 @@ class DelayedCall(object):
         self._unlink()
 
     def dispatch(self):
+        success = True
         if not self.canceled:
             when = "While handling %s" % self.name
             start = clock()
-            trapcall.trap_call(when, self.function, *self.args, **self.kwargs)
+            success = trapcall.trap_call(when, self.function, *self.args,
+                    **self.kwargs)
             end = clock()
             if end-start > 0.5:
                 logging.timing("%s too slow (%.3f secs)",
@@ -90,6 +92,7 @@ class DelayedCall(object):
                                self.name, total)
                 cumulative[self.name] = 0
         self._unlink()
+        return success
 
 class Scheduler(object):
     def __init__(self):
@@ -105,7 +108,7 @@ class Scheduler(object):
         heapq.heappush(self.heap, (scheduledTime, dc))
         return dc
 
-    def nextTimeout(self):
+    def next_timeout(self):
         if len(self.heap) == 0:
             return None
         else:
@@ -114,13 +117,13 @@ class Scheduler(object):
     def hasPendingTimeout(self):
         return len(self.heap) > 0 and self.heap[0][0] < clock()
 
-    def processNextTimeout(self):
+    def process_next_timeout(self):
         time, dc = heapq.heappop(self.heap)
-        dc.dispatch()
+        return dc.dispatch()
 
     def processTimeouts(self):
         while self.hasPendingTimeout():
-            self.processNextTimeout()
+            self.process_next_timeout()
 
 class CallQueue(object):
     def __init__(self):
@@ -138,7 +141,7 @@ class CallQueue(object):
 
     def processNextIdle(self):
         dc = self.queue.get()
-        dc.dispatch()
+        return dc.dispatch()
 
     def hasPendingIdle(self):
         return not self.queue.empty()
@@ -148,10 +151,10 @@ class CallQueue(object):
             self.processNextIdle()
 
 class ThreadPool(object):
-    """The thread pool is used to handle calls like gethostbyname() that block
-    and there's no asynchronous workaround.  What we do instead is call them
-    in a separate thread and return the result in a callback that executes in
-    the event loop.
+    """The thread pool is used to handle calls like gethostbyname()
+    that block and there's no asynchronous workaround.  What we do
+    instead is call them in a separate thread and return the result in
+    a callback that executes in the event loop.
     """
     THREADS = 3
 
@@ -163,12 +166,12 @@ class ThreadPool(object):
     def initThreads(self):
         while len(self.threads) < ThreadPool.THREADS:
             t = threading.Thread(name='ThreadPool - %d' % len(self.threads),
-                    target=self.threadLoop)
+                                 target=self.thread_loop)
             t.setDaemon(True)
             t.start()
             self.threads.append(t)
 
-    def threadLoop(self):
+    def thread_loop(self):
         while True:
             nextItem = self.queue.get()
             if nextItem == "QUIT":
@@ -205,14 +208,15 @@ class ThreadPool(object):
                 raise
             except:
                 pass
-            
+
 class EventLoop(signals.SignalEmitter):
     def __init__(self):
-        signals.SignalEmitter.__init__(self, 'thread-will-start', 
-                                             'thread-started', 
-                                             'thread-did-start', 
-                                             'begin-loop', 
-                                             'end-loop')
+        signals.SignalEmitter.__init__(self, 'thread-will-start',
+                                       'thread-started',
+                                       'thread-did-start',
+                                       'begin-loop',
+                                       'end-loop',
+                                       'event-finished')
         self.scheduler = Scheduler()
         self.idleQueue = CallQueue()
         self.urgentQueue = CallQueue()
@@ -253,7 +257,8 @@ class EventLoop(signals.SignalEmitter):
             logging.warn("Error waking up eventloop (%s)", e)
 
     def callInThread(self, callback, errback, function, name, *args, **kwargs):
-        self.threadPool.queueCall(callback, errback, function, name, *args, **kwargs)
+        self.threadPool.queueCall(callback, errback, function, name,
+                                  *args, **kwargs)
 
     def loop(self):
         self.loop_ready.set()
@@ -264,12 +269,12 @@ class EventLoop(signals.SignalEmitter):
         while not self.quitFlag:
             self.emit('begin-loop')
             self.clearRemovedCallbacks()
-            timeout = self.scheduler.nextTimeout()
+            timeout = self.scheduler.next_timeout()
             readfds = self.readCallbacks.keys()
             writefds = self.writeCallbacks.keys()
             try:
-                readables, writeables, _ = select.select(readfds, writefds, [],
-                                                         timeout)
+                readables, writeables, _ = select.select(readfds, writefds,
+                                                         [], timeout)
             except select.error, (err, detail):
                 if err == errno.EINTR:
                     logging.warning ("eventloop: %s", detail)
@@ -277,49 +282,61 @@ class EventLoop(signals.SignalEmitter):
                     raise
             if self.quitFlag:
                 break
-            self.urgentQueue.processIdles()
+            self._process_urgent_events()
             for event in self.generateEvents(readables, writeables):
-                event()
+                success = event()
+                self.emit('event-finished', success)
                 if self.quitFlag:
                     break
-                self.urgentQueue.processIdles()
+                self._process_urgent_events()
                 if self.quitFlag:
                     break
             self.emit('end-loop')
 
-    def generateEvents(self, readables, writeables):
-        """Generator that creates the list of events that should be dealt with
-        on this iteration of the event loop.  This includes all socket
-        read/write callbacks, timeouts and idle calls.  "events" are
-        implemented as functions that should be called with no arguments.
-        """
+    def _process_urgent_events(self):
+        queue = self.urgentQueue
+        while queue.hasPendingIdle() and not queue.quit_flag:
+            success = queue.processNextIdle()
+            self.emit('event-finished', success)
 
+    def generateEvents(self, readables, writeables):
+        """Generator that creates the list of events that should be
+        dealt with on this iteration of the event loop.  This includes
+        all socket read/write callbacks, timeouts and idle calls.
+
+        "events" are implemented as functions that should be called
+        with no arguments.
+        """
         for callback in self.generateCallbacks(writeables,
-                self.writeCallbacks, self.removedWriteCallbacks):
+                                               self.writeCallbacks,
+                                               self.removedWriteCallbacks):
             yield callback
         for callback in self.generateCallbacks(readables,
-                self.readCallbacks, self.removedReadCallbacks):
+                                               self.readCallbacks,
+                                               self.removedReadCallbacks):
             yield callback
         while self.scheduler.hasPendingTimeout():
-            yield self.scheduler.processNextTimeout
+            yield self.scheduler.process_next_timeout
         while self.idleQueue.hasPendingIdle():
             yield self.idleQueue.processNextIdle
 
-    def generateCallbacks(self, readyList, map, removed):
+    def generateCallbacks(self, readyList, map_, removed):
         for fd in readyList:
             try:
-                function = map[fd]
+                function = map_[fd]
             except KeyError:
-                # this can happen the write callback removes the read callback
-                # or vise versa
+                # this can happen the write callback removes the read
+                # callback or vise versa
                 pass
             else:
                 if fd in removed:
                     continue
                 when = "While talking to the network"
                 def callbackEvent():
-                    if not trapcall.trap_call(when, function):
-                        del map[fd] 
+                    success = trapcall.trap_call(when, function)
+                    if not success:
+                        del map_[fd]
+                    return success
                 yield callbackEvent
 
     def quit(self):
@@ -330,34 +347,35 @@ class EventLoop(signals.SignalEmitter):
 _eventLoop = EventLoop()
 
 def addReadCallback(socket, callback):
-    """Add a read callback.  When socket is ready for reading, callback will
-    be called.  If there is already a read callback installed, it will be
-    replaced.
+    """Add a read callback.  When socket is ready for reading,
+    callback will be called.  If there is already a read callback
+    installed, it will be replaced.
     """
     _eventLoop.addReadCallback(socket, callback)
 
 def removeReadCallback(socket):
-    """Remove a read callback.  If there is not a read callback installed for
-    socket, a KeyError will be thrown.
+    """Remove a read callback.  If there is not a read callback
+    installed for socket, a KeyError will be thrown.
     """
     _eventLoop.removeReadCallback(socket)
 
 def addWriteCallback(socket, callback):
-    """Add a write callback.  When socket is ready for writing, callback will
-    be called.  If there is already a write callback installed, it will be
-    replaced.
+    """Add a write callback.  When socket is ready for writing,
+    callback will be called.  If there is already a write callback
+    installed, it will be replaced.
     """
     _eventLoop.addWriteCallback(socket, callback)
 
 def removeWriteCallback(socket):
-    """Remove a write callback.  If there is not a write callback installed for
-    socket, a KeyError will be thrown.
+    """Remove a write callback.  If there is not a write callback
+    installed for socket, a KeyError will be thrown.
     """
     _eventLoop.removeWriteCallback(socket)
 
 def stopHandlingSocket(socket):
-    """Convience function to that removes both the read and write callback for
-    a socket if they exist."""
+    """Convience function to that removes both the read and write
+    callback for a socket if they exist.
+    """
     try:
         removeReadCallback(socket)
     except KeyError:
@@ -369,27 +387,26 @@ def stopHandlingSocket(socket):
 
 def addTimeout(delay, function, name, args=None, kwargs=None):
     """Schedule a function to be called at some point in the future.
-    Returns a DelayedCall object that can be used to cancel the call.
+    Returns a ``DelayedCall`` object that can be used to cancel the
+    call.
     """
-
     dc = _eventLoop.scheduler.addTimeout(delay, function, name, args, kwargs)
     return dc
 
 def addIdle(function, name, args=None, kwargs=None):
     """Schedule a function to be called when we get some spare time.
-    Returns a DelayedCall object that can be used to cancel the call.
+    Returns a ``DelayedCall`` object that can be used to cancel the
+    call.
     """
-
     dc = _eventLoop.idleQueue.addIdle(function, name, args, kwargs)
     _eventLoop.wakeup()
     return dc
 
 def addUrgentCall(function, name, args=None, kwargs=None):
-    """Schedule a function to be called as soon as possible.  This method
-    should be used for things like GUI actions, where the user is waiting on
-    us.
+    """Schedule a function to be called as soon as possible.  This
+    method should be used for things like GUI actions, where the user
+    is waiting on us.
     """
-
     dc = _eventLoop.urgentQueue.addIdle(function, name, args, kwargs)
     _eventLoop.wakeup()
     return dc
@@ -404,7 +421,6 @@ lt = None
 
 profile_file = None
 
-
 def startup():
     threadPoolInit()
 
@@ -412,7 +428,8 @@ def startup():
         import profile
         def start_loop():
             _eventLoop.loop()
-        profile.runctx('_eventLoop.loop()', globals(), locals(), profile_file + ".event_loop")
+        profile.runctx('_eventLoop.loop()', globals(), locals(),
+                       profile_file + ".event_loop")
 
     global lt
     if profile_file:
@@ -432,18 +449,6 @@ def quit():
     _eventLoop.quit()
     _eventLoop.wakeup()
 
-def finished():
-    """Returns True if the eventloop is done with it's work and has quit, or
-    is about to quit.
-    """
-
-    if _eventLoop.quitFlag:
-        # call wakeup() as a precaution to make sure we really are quitting.
-        _eventLoop.wakeup() 
-        return True
-    else:
-        return False
-
 def connect(signal, callback):
     _eventLoop.connect(signal, callback)
 
@@ -460,12 +465,12 @@ def threadPoolQuit():
 def threadPoolInit():
     _eventLoop.threadPool.initThreads()
 
-def asIdle(func):
+def as_idle(func):
     """Decorator to make a methods run as an idle function
 
     Suppose you have 2 methods, foo and bar
 
-    @asIdle
+    @as_idle
     def foo():
         # database operations
 
@@ -474,41 +479,40 @@ def asIdle(func):
 
     Then calling foo() is exactly the same as calling addIdle(bar).
     """
-
     def queuer(*args, **kwargs):
-        return addIdle(func, "%s() (using asIdle)" % func.__name__, args=args, kwargs=kwargs)
+        return addIdle(func, "%s() (using as_idle)" % func.__name__,
+                       args=args, kwargs=kwargs)
     return queuer
 
-def asUrgent(func):
-    """Like asIdle, but uses addUrgentCall() instead of addIdle()."""
-
+def as_urgent(func):
+    """Like ``as_idle``, but uses ``addUrgentCall()`` instead of
+    ``addIdle()``.
+    """
     def queuer(*args, **kwargs):
-        return addUrgentCall(func, "%s() (using asUrgent)" % func.__name__, args=args, kwargs=kwargs)
+        return addUrgentCall(func, "%s() (using as_urgent)" % func.__name__,
+                             args=args, kwargs=kwargs)
     return queuer
 
-def checkHeapSize():
-    logging.info ("Heap size: %d.", len(_eventLoop.scheduler.heap))
-    addTimeout(5, checkHeapSize, "Check Heap Size")
-
 def idle_iterate(func, name, args=None, kwargs=None):
-    """Iterate over a generator function using addIdle for each iteration.
+    """Iterate over a generator function using addIdle for each
+    iteration.
 
-    This allows long running functions to be split up into distinct steps,
-    after each step other idle functions will have a chance to run.
+    This allows long running functions to be split up into distinct
+    steps, after each step other idle functions will have a chance to
+    run.
 
-    For example:
+    For example::
 
-    def foo(x, y, z):
-        # do some computation
-        yield
-        # more computation
-        yield
-        # more computation
-        yield
+        def foo(x, y, z):
+            # do some computation
+            yield
+            # more computation
+            yield
+            # more computation
+            yield
 
-    eventloop.idle_iterate(foo, 'Foo', args=(1, 2, 3))
+        eventloop.idle_iterate(foo, 'Foo', args=(1, 2, 3))
     """
-
     if args is None:
         args = ()
     if kwargs is None:
@@ -523,12 +527,15 @@ def _idle_iterate_step(iter, name):
         return
     else:
         if rv is not None:
-            logging.warn("idle_iterate yield value ignored: %s (%s)", 
+            logging.warn("idle_iterate yield value ignored: %s (%s)",
                     rv, name)
         addIdle(_idle_iterate_step, name, args=(iter, name))
 
 def idle_iterator(func):
-    """Decorator to wrap a generator function in a idle_iterate() call."""
+    """Decorator to wrap a generator function in a ``idle_iterate()``
+    call.
+    """
     def queuer(*args, **kwargs):
-        return idle_iterate(func, "%s() (using idle_iterator)" % func.__name__, args=args, kwargs=kwargs)
+        return idle_iterate(func, "%s() (using idle_iterator)" % func.__name__, 
+                            args=args, kwargs=kwargs)
     return queuer
