@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 # this exception statement from your version. If you delete this exception
 # statement from all source files in the program, then also delete it here.
 
-"""``miro.frontends.widgets.application -- The application module
+"""``miro.frontends.widgets.application`` -- The application module
 holds :class:`Application` and the portable code to handle the high
 level running of the Miro application.
 
@@ -58,6 +58,7 @@ from miro.frontends.widgets import dialogs
 from miro.frontends.widgets import newsearchfeed
 from miro.frontends.widgets import newfeed
 from miro.frontends.widgets import newfolder
+from miro.frontends.widgets import itemedit
 from miro.frontends.widgets import addtoplaylistdialog
 from miro.frontends.widgets import removefeeds
 from miro.frontends.widgets import diagnostics
@@ -73,6 +74,7 @@ from miro.frontends.widgets import rundialog
 from miro.frontends.widgets import watchedfolders
 from miro.frontends.widgets import quitwhiledownloading
 from miro.frontends.widgets import firsttimedialog
+from miro.frontends.widgets.widgetconst import MAX_VOLUME
 from miro.frontends.widgets.window import MiroWindow
 from miro.plat.frontends.widgets.threads import call_on_ui_thread
 from miro.plat.frontends.widgets.widgetset import Rect
@@ -291,7 +293,7 @@ class Application:
 
     def up_volume(self):
         slider = self.window.videobox.volume_slider
-        v = min(slider.get_value() + 0.05, 1.0)
+        v = min(slider.get_value() + 0.05, MAX_VOLUME)
         slider.set_value(v)
         self.on_volume_change(slider, v)
         self.on_volume_set(slider)
@@ -485,7 +487,7 @@ class Application:
                 else:
                     messages.DeleteVideo(mem.id).send_to_backend()
 
-    def rename_item(self):
+    def edit_item(self):
         selection = app.item_list_controller_manager.get_selection()
         selection = [s for s in selection if s.downloaded]
 
@@ -494,22 +496,9 @@ class Application:
 
         item_info = selection[0]
 
-        title = _('Rename Item')
-        description = _('Enter the new name for the item')
-        text = item_info.name
-
-        name = dialogs.ask_for_string(title, description, initial_text=text)
-        if name:
-            messages.RenameVideo(item_info.id, name).send_to_backend()
-
-    def revert_item_name(self):
-        selection = app.item_list_controller_manager.get_selection()
-        selection = [s for s in selection if s.downloaded]
-
-        if not selection:
-            return
-        item_info = selection[0]
-        messages.RevertItemTitle(item_info.id).send_to_backend()
+        change_dict = itemedit.run_dialog(item_info)
+        if change_dict:
+            messages.EditItem(item_info.id, change_dict).send_to_backend()
 
     def save_item(self):
         selection = app.item_list_controller_manager.get_selection()
@@ -571,14 +560,23 @@ class Application:
             messages.NewFeedFolder(name, section, child_ids).send_to_backend()
 
     def add_new_guide(self):
-        url = self.ask_for_url(_('Add Site'),
-                _('Enter the URL of the site to add'),
-                _('Add Site - Invalid URL'),
-                _('The address you entered is not a valid url.\nPlease check the URL and try again.\n\nEnter the URL of the site to add'))
+        url = self.ask_for_url(_('Add Website'),
+                _('Enter the URL of the website to add'),
+                _('Add Website - Invalid URL'),
+                _("The address you entered is not a valid url.\n"
+                  "Please check the URL and try again.\n\n"
+                  "Enter the URL of the website to add"))
 
         if url is not None:
             messages.NewGuide(url).send_to_backend()
 
+    def remove_something(self):
+        t, infos = app.tab_list_manager.get_selection_and_children()
+        if t in ('feed', 'audio-feed'):
+            self.remove_feeds(infos)
+        elif t in('site'):
+            self.remove_sites(infos)
+
     def remove_current_feed(self):
         t, channel_infos = app.tab_list_manager.get_selection_and_children()
         if t in ('feed', 'audio-feed'):
@@ -725,8 +723,8 @@ class Application:
             description = _('Enter a new name for the playlist folder %(name)s',
                             {"name": info.name})
         elif t == 'site':
-            title = _('Rename Site')
-            description = _('Enter a new name for the site %(name)s',
+            title = _('Rename Website')
+            description = _('Enter a new name for the website %(name)s',
                             {"name": info.name})
 
         else:
@@ -769,20 +767,23 @@ class Application:
     def remove_current_site(self):
         t, infos = app.tab_list_manager.get_selection()
         if t == 'site':
-            title = ngettext('Remove site', 'Remove sites', len(infos))
-            description = ngettext(
-                'Are you sure you want to remove this site?',
-                'Are you sure you want to remove these %(count)s sites?',
-                len(infos),
-                {"count": len(infos)}
-                )
+            self.remove_sites(infos)
+    
+    def remove_sites(self, infos):
+        title = ngettext('Remove website', 'Remove websites', len(infos))
+        description = ngettext(
+            'Are you sure you want to remove this website?',
+            'Are you sure you want to remove these %(count)s websites?',
+            len(infos),
+            {"count": len(infos)}
+            )
 
-            ret = dialogs.show_choice_dialog(title, description,
-                    [dialogs.BUTTON_REMOVE, dialogs.BUTTON_CANCEL])
+        ret = dialogs.show_choice_dialog(title, description,
+                [dialogs.BUTTON_REMOVE, dialogs.BUTTON_CANCEL])
 
-            if ret == dialogs.BUTTON_REMOVE:
-                for si in infos:
-                    messages.DeleteSite(si.id).send_to_backend()
+        if ret == dialogs.BUTTON_REMOVE:
+            for si in infos:
+                messages.DeleteSite(si.id).send_to_backend()
 
     def quit_ui(self):
         """Quit  out of the UI event loop."""
@@ -1008,8 +1009,9 @@ class WidgetsMessageHandler(messages.MessageHandler):
         self.dbupgrade_progress_dialog = None
 
     def handle_startup_failure(self, message):
-        dialogs.show_message(message.summary, message.description,
-                dialogs.CRITICAL_MESSAGE)
+        if message.summary:
+            dialogs.show_message(message.summary, message.description,
+                    dialogs.CRITICAL_MESSAGE)
         app.widgetapp.do_quit()
 
     def handle_startup_success(self, message):
