@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -141,7 +141,7 @@ class Browser(widgetset.Browser):
         self.seen_cache[url] = 1
         self.navigate(url)
 
-    def should_load_url(self, url):
+    def should_load_url(self, url, mimetype=None):
         """Returns True if the Miro browser should handle the url and False
         otherwise.
 
@@ -150,13 +150,16 @@ class Browser(widgetset.Browser):
         * if the url is something that Miro should download instead
         * other things?
         """
-        logging.debug("got %s", url)
+        if mimetype is not None:
+            logging.debug("got %s (%s)" % (url, mimetype))
+        else:
+            logging.debug("got %s" % url)
 
         if url in self.seen_cache:
             del self.seen_cache[url]
             return True
 
-        url = util.toUni(url)
+        url = util.to_uni(url)
         if subscription.is_subscribe_link(url):
             messages.SubscriptionLinkClicked(url).send_to_backend()
             return False
@@ -175,6 +178,11 @@ class Browser(widgetset.Browser):
             messages.DownloadURL(url, lambda x: call_on_ui_thread(self.handle_unknown_url, x)).send_to_backend()
             return False
 
+        if mimetype is not None and filetypes.is_allowed_mimetype(mimetype):
+            logging.debug("miro wants to handle %s", url)
+            messages.DownloadURL(url, lambda x: call_on_ui_thread(self.handle_unknown_url, x)).send_to_backend()
+            return False
+
         return True
 
 class BrowserNav(widgetset.VBox):
@@ -189,16 +197,16 @@ class BrowserNav(widgetset.VBox):
         self.pack_start(separator.HThinSeparator((0.6, 0.6, 0.6)))
         self.pack_start(self.browser, expand=True)
 
-        self.toolbar.connect('browser-back', self._on_browser_back)
-        self.toolbar.connect('browser-forward', self._on_browser_forward)
-        self.toolbar.connect('browser-reload', self._on_browser_reload)
-        self.toolbar.connect('browser-stop', self._on_browser_stop)
-        self.toolbar.connect('browser-home', self._on_browser_home)
-        self.toolbar.connect('browser-download', self._on_browser_download)
-        self.toolbar.connect('browser-open', self._on_browser_open)
+        self.toolbar.connect_weak('browser-back', self._on_browser_back)
+        self.toolbar.connect_weak('browser-forward', self._on_browser_forward)
+        self.toolbar.connect_weak('browser-reload', self._on_browser_reload)
+        self.toolbar.connect_weak('browser-stop', self._on_browser_stop)
+        self.toolbar.connect_weak('browser-home', self._on_browser_home)
+        self.toolbar.connect_weak('browser-download', self._on_browser_download)
+        self.toolbar.connect_weak('browser-open', self._on_browser_open)
 
-        self.browser.connect('net-start', self._on_net_start)
-        self.browser.connect('net-stop', self._on_net_stop)
+        self.browser.connect_weak('net-start', self._on_net_start)
+        self.browser.connect_weak('net-stop', self._on_net_stop)
 
     def enable_disable_navigation(self):
         if self.browser.can_go_back():
