@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -51,12 +51,15 @@ def run_dialog(obj, report):
             vbox = widgetset.VBox(spacing=5)
 
             lab = widgetset.Label(_(
-                "%(appname)s has encountered an internal error.  You can help us track "
-                "down this problem and fix it by submitting an error report.",
+                "%(appname)s has encountered an internal error.  You can "
+                "help us track down this problem and fix it by submitting "
+                "an error report.",
                 {"appname": config.get(prefs.SHORT_APP_NAME)}
                 ))
 
             lab.set_wrap(True)
+            lab.set_size_request(600, -1)
+
             vbox.pack_start(widgetutil.align_left(lab))
 
             cbx = widgetset.Checkbox(_(
@@ -68,8 +71,8 @@ def run_dialog(obj, report):
             lab2 = widgetset.Label(_("Describe what you were doing when you got this error:"))
             vbox.pack_start(widgetutil.align_left(lab2))
 
-            text = widgetset.TextEntry()
-            text.set_width(45)
+            text = widgetset.MultilineTextEntry()
+            text.set_size_request(600, 100)
             vbox.pack_start(widgetutil.align_left(text))
 
             window.set_extra_widget(vbox)
@@ -81,9 +84,7 @@ def run_dialog(obj, report):
                 messages.ReportCrash(report, text.get_text(), cbx.get_checked()).send_to_backend()
             else:
                 return IGNORE_ERRORS
-        except (SystemExit, KeyboardInterrupt):
-            raise
-        except:
+        except StandardError:
             logging.exception("crashdialog threw exception.")
     finally:
         window.destroy()
