@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -152,8 +152,8 @@ class DisplayManager(object):
             if klass.should_display(tab_type, selected_tabs):
                 self.select_display(klass(tab_type, selected_tabs))
                 return
-        raise AssertionError("Can't find display for %s %s" % (tabs,
-            selected_tabs))
+        raise AssertionError(
+            "Can't find display for %s %s" % (tab_type, selected_tabs))
 
     def select_display(self, display):
         """Select a display and clear out the current display stack."""
@@ -565,8 +565,8 @@ class MultipleSelectionDisplay(TabDisplay):
                         {"count": self.child_count}))
             elif tab_type == "site":
                 label_parts.append(ngettext(
-                        '%(count)d Site Selected',
-                        '%(count)d Sites Selected',
+                        '%(count)d Website Selected',
+                        '%(count)d Websites Selected',
                         self.child_count,
                         {"count": self.child_count}))
             else:
