@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,7 +37,6 @@ import gtk
 from miro import app
 from miro import config
 from miro import prefs
-from miro import menubar
 from miro import signals
 from miro import dialogs
 from miro.gtcache import gettext as _
@@ -47,15 +46,14 @@ from miro.frontends.widgets import menus
 from miro.plat import resources
 from miro.plat import utils
 
-alive_windows = set() # Keeps the objects alive until destroy() is called
+# keeps the objects alive until destroy() is called
+alive_windows = set()
 running_dialogs = set()
 
 def __get_fullscreen_stock_id():
     try:
         return gtk.STOCK_FULLSCREEN
-    except (SystemExit, KeyboardInterrupt):
-        raise
-    except:
+    except StandardError:
         pass
 
 STOCK_IDS = {
@@ -77,14 +75,11 @@ STOCK_IDS = {
 
 for i in range(1, 13):
     name = 'F%d' % i
-    keymap.menubar_key_map[getattr(menubar, name)] = name
+    keymap.menubar_key_map[getattr(menus, name)] = name
 
 def get_accel_string(shortcut):
     mod_str = ''.join(keymap.menubar_mod_map[mod] for mod in shortcut.modifiers)
-    try:
-        key_str = keymap.menubar_key_map[shortcut.key]
-    except KeyError:
-        key_str = shortcut.key
+    key_str = keymap.menubar_key_map.get(shortcut.shortcut, shortcut.shortcut)
     return mod_str + key_str
 
 def get_stock_id(n):
@@ -135,6 +130,13 @@ class WindowBase(signals.SignalEmitter):
         self.create_signal('key-press')
         self.create_signal('show')
         self.create_signal('hide')
+        # FIXME - this is a weird place to have the menu code because
+        # it causes all WindowBase subclasses to have all this extra
+        # menu stuff.
+        self.menu_structure = None
+        self.menu_action_groups = None
+        self._merge_id = None
+        self._subtitle_tracks_cached = None
         self._setup_ui_manager()
 
     def set_window(self, window):
@@ -151,54 +153,84 @@ class WindowBase(signals.SignalEmitter):
 
     def calc_use_custom_style(self):
         base = self._window.style.base[gtk.STATE_NORMAL]
-        # Decide if we should use a custom style.  Right now the formula is
-        # the base color is a very light shade of gray/white (lighter than
-        # #f0f0f0).
+        # Decide if we should use a custom style.  Right now the
+        # formula is the base color is a very light shade of
+        # gray/white (lighter than #f0f0f0).
         self.use_custom_style = ((base.red == base.green == base.blue) and
                 base.red >= 61680)
 
     def connect_menu_keyboard_shortcuts(self):
         self._window.add_accel_group(self.ui_manager.get_accel_group())
 
+    def _add_menu(self, menu, outstream, parent=None):
+        outstream.write('<menu action="%s">' % menu.action)
+        for mem in menu.menuitems:
+            if isinstance(mem, menus.Menu):
+                self._add_menu(mem, outstream, menu)
+            elif isinstance(mem, menus.Separator):
+                self._add_separator(mem, outstream)
+            elif isinstance(mem, menus.MenuItem):
+                self._add_menuitem(mem, outstream)
+        outstream.write('</menu>')
+
+    def _add_menuitem(self, menu, outstream):
+        if menu.action not in ("NoneAvailable", "SubtitlesSelect"):
+            outstream.write('<menuitem action="%s" />' % menu.action)
+
+    def _add_separator(self, menu, outstream):
+        outstream.write("<separator />")
+
     def _setup_ui_manager(self):
+        self.menu_structure = menus.get_menu()
+
+        # make modifications to the menu structure here
+
+        # on gtk-x11, we don't have a CheckVersion option because
+        # we update with the package system.
+        this_platform = config.get(prefs.APP_PLATFORM)
+        if this_platform == 'gtk-x11':
+            video_menu = self.menu_structure.get("VideoMenu")
+            video_menu.remove("CheckVersion")
+
+        # generate action groups after making all modifications
+        mag = menus.generate_action_groups(self.menu_structure)
+        self.menu_action_groups = mag
+
         self.ui_manager = gtk.UIManager()
         self.make_actions()
-        uistring = StringIO.StringIO()
-        uistring.write('<ui><menubar name="MiroMenu">')
-        extra_accelerators = []
-        for menu in menubar.menubar:
-            uistring.write('<menu action="Menu%s">' % menu.action)
-            for menuitem in menu.menuitems:
-                if isinstance(menuitem, menubar.Separator):
-                    uistring.write("<separator />")
-                else:
-                    uistring.write('<menuitem action="%s" />' % menuitem.action)
-                    if len(menuitem.shortcuts) > 1:
-                        extra_accelerators.append(menuitem)
-            uistring.write('</menu>')
-        uistring.write('</menubar>')
-        if extra_accelerators:
-            for menuitem in extra_accelerators:
-                for shortcut in menuitem.shortcuts[1:]:
-                    uistring.write('<accelerator action="%s%i" />' % (menuitem.action, id(shortcut)))
-        uistring.write('</ui>')
-        self.ui_manager.add_ui_from_string(uistring.getvalue())
 
-    def make_action(self, action, label, shortcuts=None):
+        outstream = StringIO.StringIO()
+        outstream.write('<ui><menubar name="MiroMenu">')
+        extra_accelerators = []
+        for mem in self.menu_structure.menuitems:
+            self._add_menu(mem, outstream)
+        outstream.write('</menubar>')
+
+        for mem in self.menu_structure:
+            if ((not isinstance(mem, menus.MenuItem) or
+                 len(mem.shortcuts) <= 1)):
+                continue
+            for shortcut in mem.shortcuts[1:]:
+                outstream.write('<accelerator action="%s%i" />' % \
+                                (mem.action, id(shortcut)))
+        outstream.write('</ui>')
+        self.ui_manager.add_ui_from_string(outstream.getvalue())
+
+    def make_action(self, action, label, shortcuts=None, groups=None):
         gtk_action = gtk.Action(action, label, None, get_stock_id(action))
         callback = menus.lookup_handler(action)
         if callback is not None:
             gtk_action.connect("activate", self.on_activate, callback)
-        action_group_name = menus.get_action_group_name(action)
+        action_group_name = groups[0]
         action_group = self.action_groups[action_group_name]
         if shortcuts is None or len(shortcuts) == 0:
             action_group.add_action(gtk_action)
         else:
             action_group.add_action_with_accel(gtk_action,
-                    get_accel_string(shortcuts[0]))
+                                               get_accel_string(shortcuts[0]))
             for shortcut in shortcuts[1:]:
-                extra_action = gtk.Action(action + str(id(shortcut)), '', None,
-                                          None)
+                extra_action = gtk.Action(action + str(id(shortcut)), '',
+                                          None, None)
                 extra_action.set_visible(False)
                 if callback is not None:
                     extra_action.connect('activate', self.on_activate,
@@ -206,21 +238,59 @@ class WindowBase(signals.SignalEmitter):
                 action_group.add_action_with_accel(extra_action,
                                                    get_accel_string(shortcut))
 
+    def make_check_action(self, action, label, groups, callback, index,
+                          group=None):
+        gtk_action = gtk.RadioAction(action, label, None, None, index)
+        if group is not None:
+            gtk_action.set_group(group)
+        gtk_action.connect("activate", callback, index)
+        self.action_groups[groups[0]].add_action(gtk_action)
+
     def make_actions(self):
         self.action_groups = {}
-        for name in menus.action_group_names():
+        for name in self.menu_action_groups.keys():
             self.action_groups[name] = gtk.ActionGroup(name)
 
-        for menu in menubar.menubar:
-            self.make_action('Menu' + menu.action, menu.label)
-            for menuitem in menu.menuitems:
-                if isinstance(menuitem, menubar.Separator):
-                    continue
-                self.make_action(menuitem.action, menuitem.label,
-                        menuitem.shortcuts)
+        self.action_groups["Subtitles"] = gtk.ActionGroup("Subtitles")
+
+        for mem in self.menu_structure:
+            if isinstance(mem, menus.Separator):
+                continue
+            if isinstance(mem, menus.Menu):
+                self.make_action(mem.action, mem.label,
+                                 groups=mem.groups)
+            elif isinstance(mem, menus.MenuItem):
+                self.make_action(mem.action, mem.label, mem.shortcuts,
+                                 mem.groups)
+
+        # make a bunch of SubtitleTrack# actions
+        self.make_check_action("SubtitlesDisabled", _("Disable Subtitles"),
+                               ["AlwaysOn"], self.on_subtitles_change, -1)
+        radio_group = self.action_groups["AlwaysOn"].get_action("SubtitlesDisabled")
+        for i in range(199):
+            self.make_check_action("SubtitleTrack%d" % i, "", ["AlwaysOn"],
+                                   self.on_subtitles_change, i, radio_group)
+
         for action_group in self.action_groups.values():
             self.ui_manager.insert_action_group(action_group, -1)
 
+    def on_subtitles_select(self, action, track_index):
+        action_group = self.action_groups["AlwaysOn"]
+        action_group.get_action("SubtitlesDisabled").current_value = -2
+        app.playback_manager.open_subtitle_file()
+
+    def on_subtitles_change(self, action, track_index):
+        if hasattr(self, "_ignore_on_subtitles_change"):
+            return
+        if action.get_property("current-value") != action.get_property("value"):
+            return
+        action_group = self.action_groups["AlwaysOn"]
+        action_group.get_action("SubtitlesDisabled").current_value = track_index
+        if track_index == -1:
+            app.video_renderer.disable_subtitles()
+        else:
+            app.video_renderer.enable_subtitle_track(track_index)
+
     def on_activate(self, action, callback):
         callback()
 
@@ -228,8 +298,8 @@ class Window(WindowBase):
     """The main Miro window.  """
 
     def __init__(self, title, rect=None):
-        """Create the Miro Main Window.  Title is the name to give the window,
-        rect specifies the position it should have on screen.
+        """Create the Miro Main Window.  Title is the name to give the
+        window, rect specifies the position it should have on screen.
         """
         WindowBase.__init__(self)
         self.set_window(self._make_gtk_window())
@@ -279,9 +349,9 @@ class Window(WindowBase):
         """Set the widget that will be drawn in the content area for this
         window.
 
-        It will be allocated the entire area of the widget, except the space
-        needed for the titlebar, frame and other decorations.  When the window
-        is resized, content should also be resized.
+        It will be allocated the entire area of the widget, except the
+        space needed for the titlebar, frame and other decorations.
+        When the window is resized, content should also be resized.
         """
         self._add_content_widget(widget)
         widget._widget.show()
@@ -310,11 +380,15 @@ class MainWindow(Window):
         self.create_signal('save-dimensions')
         self.create_signal('save-maximized')
         app.menu_manager.connect('enabled-changed', self.on_menu_change)
+        app.playback_manager.connect('did-start-playing', self.on_playback_change)
+        app.playback_manager.connect('will-play', self.on_playback_change)
+        app.playback_manager.connect('did-stop', self.on_playback_change)
 
         self._window.connect('key-release-event', self.on_key_release)
         self._window.connect('window-state-event', self.on_window_state_event)
         self._window.connect('configure-event', self.on_configure_event)
         self.connect('will-close', self.on_close)
+        self._clear_subtitles_menu()
 
     def _make_gtk_window(self):
         return WrappedMainWindow()
@@ -333,7 +407,8 @@ class MainWindow(Window):
 
     def on_key_release(self, widget, event):
         if app.playback_manager.is_playing:
-            if gtk.gdk.keyval_name(event.keyval) in ('Right', 'Left', 'Up', 'Down'):
+            if gtk.gdk.keyval_name(event.keyval) in ('Right', 'Left',
+                                                     'Up', 'Down'):
                 return True
 
     def _add_menubar(self):
@@ -348,40 +423,113 @@ class MainWindow(Window):
             else:
                 action_group.set_sensitive(False)
 
-        removeFeeds = menubar.menubar.getLabel("RemoveFeeds")
-        updateFeeds = menubar.menubar.getLabel("UpdateFeeds")
-        removePlaylists = menubar.menubar.getLabel("RemovePlaylists")
-        removeItems = menubar.menubar.getLabel("RemoveItems")
+        removeSomething = self.menu_structure.get("RemoveSomething").label
+        updateFeeds = self.menu_structure.get("UpdateFeeds").label
+        removePlaylists = self.menu_structure.get("RemovePlaylists").label
+        removeItems = self.menu_structure.get("RemoveItems").label
+
+        def get_state_label(action, state):
+            menu = self.menu_structure.get(action)
+            return menu.state_labels.get(state, menu.label)
 
         for state, actions in menu_manager.states.items():
-            if "RemoveFeeds" in actions:
-                removeFeeds = menubar.menubar.getLabel("RemoveFeeds", state)
+            if "RemoveSomething" in actions:
+                removeSomething = get_state_label("RemoveSomething", state)
             if "UpdateFeeds" in actions:
-                updateFeeds = menubar.menubar.getLabel("UpdateFeeds", state)
+                updateFeeds = get_state_label("UpdateFeeds", state)
             if "RemovePlaylists" in actions:
-                removePlaylists = menubar.menubar.getLabel("RemovePlaylists", state)
+                removePlaylists = get_state_label("RemovePlaylists", state)
             if "RemoveItems" in actions:
-                removeItems = menubar.menubar.getLabel("RemoveItems", state)
+                removeItems = get_state_label("RemoveItems", state)
 
-        self.action_groups["FeedsSelected"].get_action("RemoveFeeds").set_property("label", removeFeeds)
-        self.action_groups["FeedsSelected"].get_action("UpdateFeeds").set_property("label", updateFeeds)
-        self.action_groups["PlaylistsSelected"].get_action("RemovePlaylists").set_property("label", removePlaylists)
-        self.action_groups["PlayablesSelected"].get_action("RemoveItems").set_property("label", removeItems)
+        action_groups = self.action_groups
 
-        play_pause = menubar.menubar.getLabel("PlayPauseVideo", menu_manager.play_pause_state)
-        self.action_groups["PlayPause"].get_action("PlayPauseVideo").set_property("label", play_pause)
+        def change_label(group, action, newlabel):
+            action_groups[group].get_action(action).set_property("label", newlabel)
+
+        change_label("RemoveAllowed", "RemoveSomething", removeSomething)
+        change_label("FeedsSelected", "UpdateFeeds", updateFeeds)
+        change_label("PlaylistsSelected", "RemovePlaylists", removePlaylists)
+        change_label("PlayablesSelected", "RemoveItems", removeItems)
+
+        play_pause = self.menu_structure.get("PlayPauseVideo").state_labels[menu_manager.play_pause_state]
+        change_label("PlayPause", "PlayPauseVideo", play_pause)
+
+    def on_playback_change(self, playback_manager, *extra_args):
+        self._ignore_on_subtitles_change = True
+        if app.playback_manager.is_playing_audio:
+            self._clear_subtitles_menu()
+        else:
+            tracks = app.video_renderer.get_subtitle_tracks()
+            if len(tracks) == 0:
+                self._clear_subtitles_menu()
+            else:
+                self._populate_subtitles_menu(tracks)
+        delattr(self, "_ignore_on_subtitles_change")
+
+    def _populate_subtitles_menu(self, tracks):
+        enabled_track = app.video_renderer.get_enabled_subtitle_track()
+
+        if self._subtitle_tracks_cached == (tuple(tracks), enabled_track):
+            return
+
+        self._subtitle_tracks_cached = (tuple(tracks), enabled_track)
+
+        if self._merge_id is not None:
+            self.ui_manager.remove_ui(self._merge_id)
+
+        outstream = StringIO.StringIO()
+        outstream.write('''<ui>
+<menubar name="MiroMenu">
+   <menu action="PlaybackMenu">
+      <menu action="SubtitlesMenu">
+''')
+        for i, lang in tracks:
+            outstream.write('         <menuitem action="SubtitleTrack%d"/>\n' % i)
+        outstream.write('''         <separator/>
+         <menuitem action="SubtitlesDisabled"/>
+         <menuitem action="SubtitlesSelect"/>
+      </menu>
+   </menu>
+</menubar>
+</ui>''')
+
+        self._merge_id = self.ui_manager.add_ui_from_string(outstream.getvalue())
+        
+        action_group = self.action_groups["AlwaysOn"]
+        for i, lang in tracks:
+            action_group.get_action("SubtitleTrack%d" % i).set_property("label", lang)
+
+        action_group.get_action("SubtitlesDisabled").set_property("current-value", enabled_track)
+
+    def _clear_subtitles_menu(self):
+        if self._merge_id is not None:
+            self.ui_manager.remove_ui(self._merge_id)
+            self._subtitle_tracks_cached = None
+
+        s = '''<ui>
+<menubar name="MiroMenu">
+<menu action="PlaybackMenu">
+<menu action="SubtitlesMenu">
+<menuitem action="NoneAvailable"/>
+<menuitem action="SubtitlesSelect"/>
+</menu>
+</menu>
+</menubar>
+</ui>'''
+        self._merge_id = self.ui_manager.add_ui_from_string(s)
 
     def _add_content_widget(self, widget):
         self.vbox.pack_start(widget._widget, expand=True)
 
-
-_stock = { dialogs.BUTTON_OK.text : gtk.STOCK_OK,
-           dialogs.BUTTON_CANCEL.text : gtk.STOCK_CANCEL,
-           dialogs.BUTTON_YES.text : gtk.STOCK_YES,
-           dialogs.BUTTON_NO.text : gtk.STOCK_NO,
-           dialogs.BUTTON_QUIT.text : gtk.STOCK_QUIT,
-           dialogs.BUTTON_REMOVE.text : gtk.STOCK_REMOVE,
-           dialogs.BUTTON_DELETE.text : gtk.STOCK_DELETE,
+_stock = {
+    dialogs.BUTTON_OK.text: gtk.STOCK_OK,
+    dialogs.BUTTON_CANCEL.text: gtk.STOCK_CANCEL,
+    dialogs.BUTTON_YES.text: gtk.STOCK_YES,
+    dialogs.BUTTON_NO.text: gtk.STOCK_NO,
+    dialogs.BUTTON_QUIT.text: gtk.STOCK_QUIT,
+    dialogs.BUTTON_REMOVE.text: gtk.STOCK_REMOVE,
+    dialogs.BUTTON_DELETE.text: gtk.STOCK_DELETE,
     }
 
 class DialogBase(WindowBase):
@@ -475,10 +623,14 @@ class FileOpenDialog(FileDialogBase):
     def __init__(self, title):
         FileDialogBase.__init__(self)
         self._files = None
-        self.set_window(gtk.FileChooserDialog(title,
-                               action=gtk.FILE_CHOOSER_ACTION_OPEN,
-                               buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        gtk.STOCK_OPEN, gtk.RESPONSE_OK)))
+        fcd = gtk.FileChooserDialog(title,
+                                    action=gtk.FILE_CHOOSER_ACTION_OPEN,
+                                    buttons=(gtk.STOCK_CANCEL,
+                                             gtk.RESPONSE_CANCEL,
+                                             gtk.STOCK_OPEN,
+                                             gtk.RESPONSE_OK))
+
+        self.set_window(fcd)
 
     def set_filename(self, text):
         self._window.set_filename(text)
@@ -488,16 +640,16 @@ class FileOpenDialog(FileDialogBase):
 
     def add_filters(self, filters):
         for name, ext_list in filters:
-            filter = gtk.FileFilter()
-            filter.set_name(name)
+            f = gtk.FileFilter()
+            f.set_name(name)
             for mem in ext_list:
-                filter.add_pattern('*.%s' % mem)
-            self._window.add_filter(filter)
+                f.add_pattern('*.%s' % mem)
+            self._window.add_filter(f)
 
-        filter = gtk.FileFilter()
-        filter.set_name(_('All files'))
-        filter.add_pattern('*')
-        self._window.add_filter(filter)
+        f = gtk.FileFilter()
+        f.set_name(_('All files'))
+        f.add_pattern('*')
+        self._window.add_filter(f)
 
     def get_filenames(self):
         return [utils.FilenameType(f) for f in self._files]
@@ -509,10 +661,13 @@ class FileSaveDialog(FileDialogBase):
     def __init__(self, title):
         FileDialogBase.__init__(self)
         self._files = None
-        self.set_window(gtk.FileChooserDialog(title,
-                               action=gtk.FILE_CHOOSER_ACTION_SAVE,
-                               buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        gtk.STOCK_SAVE, gtk.RESPONSE_OK)))
+        fcd = gtk.FileChooserDialog(title,
+                                    action=gtk.FILE_CHOOSER_ACTION_SAVE,
+                                    buttons=(gtk.STOCK_CANCEL,
+                                             gtk.RESPONSE_CANCEL,
+                                             gtk.STOCK_SAVE,
+                                             gtk.RESPONSE_OK))
+        self.set_window(fcd)
 
     def set_filename(self, text):
         self._window.set_current_name(text)
@@ -525,10 +680,12 @@ class DirectorySelectDialog(FileDialogBase):
         FileDialogBase.__init__(self)
         self._files = None
         choose_str =_('Choose').encode('utf-8')
-        self.set_window(gtk.FileChooserDialog(title,
-                               action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                               buttons=(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
-                                        choose_str, gtk.RESPONSE_OK)))
+        fcd = gtk.FileChooserDialog(title,
+                                    action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                    buttons=(gtk.STOCK_CANCEL,
+                                             gtk.RESPONSE_CANCEL,
+                                             choose_str, gtk.RESPONSE_OK))
+        self.set_window(fcd)
 
     def set_directory(self, text):
         self._window.set_filename(text)
@@ -542,12 +699,13 @@ class AboutDialog(Dialog):
                         _("About %(appname)s") % {
                 'appname': config.get(prefs.SHORT_APP_NAME)})
         icon_pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(
-                resources.share_path('icons/hicolor/128x128/apps/miro.png'), 48, 48)
+                resources.share_path('icons/hicolor/128x128/apps/miro.png'),
+                48, 48)
         self.packing_vbox.pack_start(gtk.image_new_from_pixbuf(icon_pixbuf))
         if config.get(prefs.APP_REVISION_NUM):
             version = "%s (%s)" % (
-                    config.get(prefs.APP_VERSION),
-                    config.get(prefs.APP_REVISION_NUM))
+                config.get(prefs.APP_VERSION),
+                config.get(prefs.APP_REVISION_NUM))
         else:
             version = "%s" % config.get(prefs.APP_VERSION)
         name_label = gtk.Label('<span size="xx-large" weight="bold">%s %s</span>' % (
@@ -610,7 +768,8 @@ class AlertDialog(DialogBase):
     def __init__(self, title, description, alert_type):
         DialogBase.__init__(self)
         message_type = type_map.get(alert_type, gtk.MESSAGE_INFO)
-        self.set_window(gtk.MessageDialog(type=message_type, message_format=description))
+        self.set_window(gtk.MessageDialog(type=message_type,
+                                          message_format=description))
         self._window.set_title(title)
 
     def add_button(self, text):
@@ -625,4 +784,5 @@ class AlertDialog(DialogBase):
         if response == gtk.RESPONSE_DELETE_EVENT:
             return -1
         else:
-            return response - 1 # response IDs started at 1
+            # response IDs start at 1
+            return response - 1
