@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -38,7 +38,9 @@ They also handle temporarily filtering out items based the user's search
 terms.
 """
 
+import re
 import sys
+import unicodedata
 
 from miro import search
 from miro import util
@@ -70,7 +72,7 @@ class ItemSort(object):
 
         Must be implemented by subclasses.
         """
-        raise NotImplentedError()
+        raise NotImplementedError()
 
     def compare(self, item, other):
         """Compare two items
@@ -98,7 +100,17 @@ class DateSort(ItemSort):
 
 class NameSort(ItemSort):
     KEY = 'name'
+    def _strip_accents(self, str):
+        nfkd_form = unicodedata.normalize('NFKD', unicode(str))
+        return u"".join([c for c in nfkd_form if not unicodedata.combining(c)])
+    def _trynum(self, str):
+        try:
+            return float(str)
+        except:
+            return self._strip_accents(str)
     def sort_key(self, item):
+        if item.name:
+            return [ self._trynum(c) for c in re.split('([0-9]+\.?[0-9]*)', item.name) ]
         return item.name
 
 class LengthSort(ItemSort):
@@ -119,6 +131,8 @@ class DescriptionSort(ItemSort):
 class FeedNameSort(ItemSort):
     KEY = 'feed-name'
     def sort_key(self, item):
+        if item.feed_name:
+            return item.feed_name.lower()
         return item.feed_name
 
 class StatusCircleSort(ItemSort):
@@ -140,15 +154,16 @@ class StatusSort(ItemSort):
     KEY = 'status'
     def sort_key(self, item):
         if item.state == 'downloading':
-            return 2 # downloading
+            return (2, ) # downloading
         elif item.downloaded and not item.video_watched:
-            return 3 # unwatched
+            return (3, ) # unwatched
         elif item.expiration_date:
-            return 4 # expiring
+            # the tuple here creates a subsort on expiration_date
+            return (4, item.expiration_date) # expiring
         elif not item.item_viewed:
-            return 0 # new
+            return (0, ) # new
         else:
-            return 1 # other
+            return (1, ) # other
 
 class ETASort(ItemSort):
     KEY = 'eta'
@@ -450,26 +465,26 @@ class ItemList(object):
     def set_new_only(self, new_only):
         """Set if only new items are to be displayed (default False)."""
         self.new_only = new_only
-        self._recalulate_hidden_items()
+        self._recalculate_hidden_items()
 
     def view_all(self):
         self.unwatched_only = False
         self.non_feed_only = False
-        self._recalulate_hidden_items()
+        self._recalculate_hidden_items()
 
     def toggle_unwatched_only(self):
         self.unwatched_only = not self.unwatched_only
-        self._recalulate_hidden_items()
+        self._recalculate_hidden_items()
 
     def toggle_non_feed(self):
         self.non_feed_only = not self.non_feed_only
-        self._recalulate_hidden_items()
+        self._recalculate_hidden_items()
 
     def set_search_text(self, search_text):
         self._search_text = search_text
-        self._recalulate_hidden_items()
+        self._recalculate_hidden_items()
 
-    def _recalulate_hidden_items(self):
+    def _recalculate_hidden_items(self):
         newly_matching = self._find_newly_matching_items()
         removed = self._remove_non_matching_items()
         self._sorter.sort_items(newly_matching)
