@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -42,7 +42,6 @@ from urlparse import urljoin
 
 from miro import app
 from miro import messages
-from miro import menubar
 from miro import subscription
 from miro.gtcache import gettext as _
 from miro.frontends.widgets import dialogs
@@ -52,6 +51,7 @@ from miro.frontends.widgets import itemlistwidgets
 from miro.frontends.widgets import imagepool
 from miro.frontends.widgets import widgetutil
 from miro.frontends.widgets import separator
+from miro.frontends.widgets import menus
 from miro.plat.frontends.widgets import widgetset
 from miro.plat import resources
 
@@ -195,23 +195,25 @@ class ItemListController(object):
         elif info.download_info is None:
             messages.StartDownload(info.id).send_to_backend()
 
+    def _toolbar_filter_changed(self):
+        for item_view in self.all_item_views():
+            item_view.model_changed()
+        self.check_for_empty_list()
+
     def on_view_all_clicked(self, button):
         self.widget.toolbar.switch_to_view_all()
         self.item_list.view_all()
-        for item_view in self.all_item_views():
-            item_view.model_changed()
+        self._toolbar_filter_changed()
 
     def on_toggle_unwatched(self, button):
         self.widget.toolbar.toggle_unwatched_only()
         self.item_list.toggle_unwatched_only()
-        for item_view in self.all_item_views():
-            item_view.model_changed()
+        self._toolbar_filter_changed()
 
     def on_toggle_non_feed(self, button):
         self.widget.toolbar.toggle_non_feed_only()
         self.item_list.toggle_non_feed()
-        for item_view in self.all_item_views():
-            item_view.model_changed()
+        self._toolbar_filter_changed()
 
     def on_sort_changed(self, object, sort_key, ascending):
         sorter = itemlist.SORT_KEY_MAP[sort_key](ascending)
@@ -224,7 +226,7 @@ class ItemListController(object):
         app.frontend_states_memory.set_sort_state(self.type, self.id, sorter)
 
     def on_key_press(self, view, key, mods):
-        if key == menubar.DELETE:
+        if key == menus.DELETE:
             return self.handle_delete()
 
     def handle_delete(self):
@@ -281,6 +283,8 @@ class ItemListController(object):
             id = item_info.id
             items = itemview.item_list.get_items(start_id=id)
             self._play_item_list(items)
+        elif name == 'play_pause':
+            app.playback_manager.play_pause()
 
     def on_selection_changed(self, item_view):
         if (item_view is not self.current_item_view and
@@ -405,6 +409,7 @@ class SimpleItemListController(ItemListController):
 
     def _on_search_changed(self, widget, search_text):
         self.set_search(search_text)
+        self.check_for_empty_list()
 
     def normal_item_views(self):
         return [self.item_view]
