@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@ code for the New Search Feed dialog.
 from miro.gtcache import gettext as _
 from miro import searchengines
 
-from miro.util import clampText
 from miro.plat.frontends.widgets import widgetset
 from miro.frontends.widgets import widgetutil
 from miro.frontends.widgets.dialogs import MainDialog
@@ -86,7 +85,8 @@ def run_dialog():
             rbg = widgetset.RadioButtonGroup()
 
             channel_rb = widgetset.RadioButton(_("Feed:"), rbg)
-            channel_option = widgetset.OptionMenu([clampText(ci.name) for ci in channels])
+            channel_option = widgetset.OptionMenu([ci.name for ci in channels])
+            channel_option.set_size_request(250, -1)
             choice_table.pack(channel_rb, 0, 0)
             choice_table.pack(channel_option, 1, 0)
 
@@ -164,9 +164,7 @@ def run_dialog():
                             url_text.get_text(),
                             term,
                             section)
-        except (SystemExit, KeyboardInterrupt):
-            raise
-        except:
+        except StandardError:
             logging.exception("newsearchfeed threw exception.")
     finally:
         window.destroy()
