@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,15 +30,18 @@ import logging
 import os
 
 from miro import app
-from miro import menubar
 from miro import prefs
 from miro import config
 from miro import signals
 from miro import messages
+from miro import filetypes
 
+from miro.gtcache import gettext as _
 from miro.plat.frontends.widgets import timer
 from miro.plat.frontends.widgets import widgetset
 from miro.frontends.widgets.displays import VideoDisplay
+from miro.frontends.widgets import menus
+from miro.frontends.widgets import dialogs
 
 class PlaybackManager (signals.SignalEmitter):
     
@@ -64,6 +67,7 @@ class PlaybackManager (signals.SignalEmitter):
         self.create_signal('selecting-file')
         self.create_signal('cant-play-file')
         self.create_signal('will-play')
+        self.create_signal('did-start-playing')
         self.create_signal('will-play-attached')
         self.create_signal('will-play-detached')
         self.create_signal('will-pause')
@@ -193,7 +197,8 @@ class PlaybackManager (signals.SignalEmitter):
             detached_window_frame = widgetset.Rect(0, 0, 800, 600)
         else:
             detached_window_frame = widgetset.Rect.from_string(detached_window_frame)
-        self.detached_window = DetachedWindow("", detached_window_frame)
+        title = self.playlist[self.position].name
+        self.detached_window = DetachedWindow(title, detached_window_frame)
         self.align = widgetset.DetachedWindowHolder()
         self.align.add(self.video_display.widget)
         self.detached_window.set_content_widget(self.align)
@@ -236,11 +241,13 @@ class PlaybackManager (signals.SignalEmitter):
         if not self.removing_video_display:
             self.stop()
 
-    def play(self):
+    def play(self, start_at=0):
         duration = self.player.get_total_playback_time()
         self.emit('will-play', duration)
         resume_time = self.playlist[self.position].resume_time
-        if (config.get(prefs.RESUME_VIDEOS_MODE)
+        if start_at > 0:
+            self.player.play_from_time(start_at)
+        elif (config.get(prefs.RESUME_VIDEOS_MODE)
                and resume_time > 10
                and not self.is_paused):
             self.player.play_from_time(resume_time)
@@ -299,15 +306,21 @@ class PlaybackManager (signals.SignalEmitter):
         self.removing_video_display = False
 
     def update_current_resume_time(self, resume_time=-1):
-        if not self.open_successful:
+        if not self.open_successful or self.player is None:
             return
+        item_info = self.playlist[self.position]
         if config.get(prefs.RESUME_VIDEOS_MODE):
             if resume_time == -1:
                 resume_time = self.player.get_elapsed_playback_time()
+                # if we are 95% of the way into the movie and less than 30
+                # seconds before the end, don't save resume time (#11956)
+                if resume_time > min(item_info.duration * 0.95,
+                        item_info.duration - 30):
+                    resume_time = 0
         else:
             resume_time = 0
-        id = self.playlist[self.position].id
-        messages.SetItemResumeTime(id, resume_time).send_to_backend()
+        m = messages.SetItemResumeTime(item_info.id, resume_time)
+        m.send_to_backend()
 
     def set_playback_rate(self, rate):
         if self.is_playing:
@@ -360,7 +373,14 @@ class PlaybackManager (signals.SignalEmitter):
             self._finish_setup_player(item_info, item_type, volume)
         def _handle_unsuccessful_sniff():
             self._finish_setup_player(item_info, "unplayable", volume)
-        widgetset.get_item_type(item_info, _handle_successful_sniff, _handle_unsuccessful_sniff)
+        if item_info.media_type_checked:
+            type = item_info.file_type
+            if type == 'other':
+                # the backend and frontend use different names for this
+                type = 'unplayable'
+            self._finish_setup_player(item_info, type, volume)
+        else:
+            widgetset.get_item_type(item_info, _handle_successful_sniff, _handle_unsuccessful_sniff)
     
     def _finish_setup_player(self, item_info, item_type, volume):
         if item_type == 'audio':
@@ -388,6 +408,7 @@ class PlaybackManager (signals.SignalEmitter):
             self.video_display.setup(item_info, volume)
             if self.detached_window is not None:
                 self.detached_window.set_title(item_info.name)
+        self.emit('did-start-playing')
         app.menu_manager.update_menus()
 
     def _build_video_player(self, item_info, volume):
@@ -409,8 +430,22 @@ class PlaybackManager (signals.SignalEmitter):
         self.is_playing_audio = True
 
     def _select_current(self):
-        volume = config.get(prefs.VOLUME_LEVEL)
         item_info = self.playlist[self.position]
+        if not config.get(prefs.PLAY_IN_MIRO):
+            if self.is_playing:
+                self.player.stop()
+                self.player = None
+                if self.video_display is not None:
+                    self.remove_video_display()
+                    self.video_display = None
+            # FIXME - do this to avoid "currently playing green thing.
+            # should be a better way.
+            self.playlist = None
+            app.widgetapp.open_file(item_info.video_path)
+            messages.MarkItemWatched(item_info.id).send_to_backend()
+            return
+
+        volume = config.get(prefs.VOLUME_LEVEL)
         self.emit('selecting-file', item_info)
         self.open_successful = False
         self._setup_player(item_info, volume)
@@ -425,7 +460,7 @@ class PlaybackManager (signals.SignalEmitter):
 
         self.cancel_update_timer()
         self.cancel_mark_as_watched()
-        if (0 <= new_position < len(self.playlist)):
+        if self.playlist is not None and (0 <= new_position < len(self.playlist)):
             self.position = new_position
             if self.is_playing:
                 self.player.stop(True)
@@ -503,6 +538,25 @@ class PlaybackManager (signals.SignalEmitter):
         self.prepare_detached_playback()
         self.schedule_update()
 
+    def open_subtitle_file(self):
+        if not self.is_playing:
+            return
+
+        pos = self.player.get_elapsed_playback_time()
+        def after_successful_select():
+            self.play(start_at=pos)
+
+        self.pause()
+
+        title = _('Open Subtitles File...')
+        filters = [(_('Subtitle files'), [ext[1:] for ext in filetypes.SUBTITLES_EXTENSIONS])]
+        filename = dialogs.ask_for_open_pathname(title, filters=filters, select_multiple=False)
+        if filename is None:
+            self.play()
+            return
+
+        self.player.select_subtitle_file(filename, after_successful_select)
+
 class DetachedWindow(widgetset.Window):
     def __init__(self, title, rect):
         widgetset.Window.__init__(self, title, rect)
@@ -530,16 +584,28 @@ def handle_key_press(key, mods):
     """Handle a playback key press events """
 
     if len(mods) != 0:
-        if set([menubar.MOD, menubar.SHIFT]) == mods:
+        if set([menus.MOD, menus.SHIFT]) == mods:
             if key in ('>', '.'): # OS X sends '.', GTK sends '>'
                 app.widgetapp.on_forward_clicked()
                 return True
             elif key in ('<', ','): # OS X sends ',', GTK sends '<'
                 app.widgetapp.on_previous_clicked()
                 return True
+
+        if set([menus.SHIFT]) == mods:
+            if key == menus.RIGHT_ARROW:
+                app.widgetapp.on_skip_forward()
+                return True
+            elif key == menus.LEFT_ARROW:
+                app.widgetapp.on_skip_backward()
+                return True
+
+        if set([menus.CTRL]) == mods and key == menus.SPACE:
+            app.playback_manager.play_pause()
+            return True
         return False
 
-    if key == menubar.ESCAPE:
+    if key == menus.ESCAPE:
         if app.playback_manager.is_fullscreen:
             app.widgetapp.on_fullscreen_clicked()
             return True
@@ -552,22 +618,22 @@ def handle_key_press(key, mods):
     if app.playback_manager.is_playing_audio:
         return False
 
-    if key == menubar.RIGHT_ARROW:
+    if key == menus.RIGHT_ARROW:
         app.widgetapp.on_skip_forward()
         return True
 
-    if key == menubar.LEFT_ARROW:
+    if key == menus.LEFT_ARROW:
         app.widgetapp.on_skip_backward()
         return True
 
-    if key == menubar.UP_ARROW:
+    if key == menus.UP_ARROW:
         app.widgetapp.up_volume()
         return True
 
-    if key == menubar.DOWN_ARROW:
+    if key == menus.DOWN_ARROW:
         app.widgetapp.down_volume()
         return True
 
-    if key == menubar.SPACE:
+    if key == menus.SPACE:
         app.playback_manager.play_pause()
         return True
