@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -487,13 +487,14 @@ class _WatchedFolderHelper(object):
         self._table = widgetset.TableView(app.watched_folder_manager.model)
         folder_cell_renderer = widgetset.CellRenderer()
         folder_cell_renderer.set_text_size(widgetconst.SIZE_SMALL)
-        folder_column = widgetset.TableColumn('folder',
-                folder_cell_renderer, value=1)
+        folder_column = widgetset.TableColumn(
+            _('folder'), folder_cell_renderer, value=1)
         folder_column.set_min_width(400)
         checkbox_cell_renderer = widgetset.CheckboxCellRenderer()
         checkbox_cell_renderer.set_control_size(widgetconst.SIZE_SMALL)
         checkbox_cell_renderer.connect('clicked', self._on_visible_clicked)
-        visible_column = widgetset.TableColumn('visible', checkbox_cell_renderer, value=2)
+        visible_column = widgetset.TableColumn(
+            _('visible'), checkbox_cell_renderer, value=2)
         visible_column.set_min_width(50)
         self._table.add_column(folder_column)
         self._table.add_column(visible_column)
@@ -617,18 +618,31 @@ class PlaybackPanel(PanelBuilder):
     def build_widget(self):
         v = widgetset.VBox()
 
-        cbx = widgetset.Checkbox(_('Always play videos in a separate window.'))
-        attach_boolean(cbx, prefs.PLAY_DETACHED)
-        v.pack_start(widgetutil.align_left(cbx, bottom_pad=6))
+        miro_cbx = widgetset.Checkbox(_('Play media in Miro.'))
+        separate_cbx = widgetset.Checkbox(_('Always play videos in a separate window.'))
+        resume_cbx = widgetset.Checkbox(_('Resume playing a video or audio item from the point it was last stopped.'))
 
-        cbx = widgetset.Checkbox(_('Resume playing a video or audio item from the point it was last stopped.'))
-        attach_boolean(cbx, prefs.RESUME_VIDEOS_MODE)
-        v.pack_start(widgetutil.align_left(cbx, bottom_pad=12))
+        subtitles_cbx = widgetset.Checkbox(_('Automatically enable movie subtitles when available.'))
 
         rbg = widgetset.RadioButtonGroup()
         play_rb = widgetset.RadioButton(_("Play video and audio items one after another"), rbg)
         stop_rb = widgetset.RadioButton(_("Stop after each video or audio item"), rbg)
-        attach_radio( [(stop_rb, True), (play_rb, False)], prefs.SINGLE_VIDEO_PLAYBACK_MODE)
+
+        attach_boolean(miro_cbx, prefs.PLAY_IN_MIRO, (separate_cbx, resume_cbx,
+                                                      subtitles_cbx, play_rb,
+                                                      stop_rb))
+        v.pack_start(widgetutil.align_left(miro_cbx, bottom_pad=6))
+
+        attach_boolean(separate_cbx, prefs.PLAY_DETACHED)
+        v.pack_start(widgetutil.align_left(separate_cbx, bottom_pad=6))
+
+        attach_boolean(resume_cbx, prefs.RESUME_VIDEOS_MODE)
+        v.pack_start(widgetutil.align_left(resume_cbx, bottom_pad=6))
+
+        attach_boolean(subtitles_cbx, prefs.ENABLE_SUBTITLES)
+        v.pack_start(widgetutil.align_left(subtitles_cbx, bottom_pad=6))
+
+        attach_radio([(stop_rb, True), (play_rb, False)], prefs.SINGLE_VIDEO_PLAYBACK_MODE)
         v.pack_start(widgetutil.align_left(play_rb), padding=2)
         v.pack_start(widgetutil.align_left(stop_rb))
 
