@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -156,8 +156,9 @@ class TabRenderer(widgetset.CustomCellRenderer):
         renderer.render_layout(context)
 
     def pack_bubbles(self, hbox, layout):
-        if getattr(self.data, 'is_updating', None):
-            updating_image = widgetutil.make_surface("icon-updating")
+        if self.updating_frame > -1:
+            image_name = 'icon-updating-%s' % self.updating_frame
+            updating_image = widgetutil.make_surface(image_name)
             alignment = cellpack.Alignment(updating_image, yalign=0.5, yscale=0.0,
                     xalign=0.0, xscale=0.0, min_width=20)
             hbox.pack(alignment)
@@ -196,7 +197,6 @@ class TabRenderer(widgetset.CustomCellRenderer):
 
 class StaticTabRenderer(TabRenderer):
     BOLD_TITLE = True
-    MIN_HEIGHT_BIG = 28
 
     def pack_bubbles(self, hbox, layout):
         if self.data.unwatched > 0:
@@ -247,6 +247,7 @@ class ItemRenderer(widgetset.CustomCellRenderer):
     UPLOAD_TOTAL_TEXT = _("Upload Total")
     DOWN_RATE_TEXT = _("Down Rate")
     DOWN_TOTAL_TEXT = _("Down Total")
+    UP_DOWN_RATIO_TEXT = _("Up/Down Ratio")
     DOWNLOAD_TEXT = _("Download")
     DOWNLOAD_TORRENT_TEXT = _("Download Torrent")
     ERROR_TEXT = _("Error")
@@ -270,6 +271,8 @@ class ItemRenderer(widgetset.CustomCellRenderer):
             'images/video-download-resume.png'))
         self.play_button = imagepool.get_surface(resources.path(
             'images/play-button.png'))
+        self.pause_playback_button = imagepool.get_surface(resources.path(
+            'images/pause-item-button.png'))
         self.thumb_overlay = imagepool.get_surface(resources.path(
             'images/thumb-overlay.png'))
         self.alert_image = imagepool.get_surface(resources.path(
@@ -550,7 +553,9 @@ class ItemRenderer(widgetset.CustomCellRenderer):
                 'visit_filelink', not (self.data.file_url and not self.data.file_url.startswith('file:')))
         hbox.pack(cellpack.align_center(fileurl_hotspot))
 
-        license_hotspot = self._make_button(layout, self.LICENSE_PAGE_TEXT, 'visit_license', not self.data.license)
+        license_hotspot = self._make_button(layout, self.LICENSE_PAGE_TEXT,
+                                            'visit_license',
+                                            not util.is_url(self.data.license))
         hbox.pack(cellpack.align_center(license_hotspot))
 
         # 12px between the normal content and the flap border and 8px between
@@ -650,7 +655,11 @@ class ItemRenderer(widgetset.CustomCellRenderer):
             if self.data.leechers is not None:
                 details_rows.append(
                     (self.DOWN_RATE_TEXT, displaytext.download_rate(self.data.down_rate), None))
-            details_rows.append((self.DOWN_TOTAL_TEXT, displaytext.size_string(self.data.down_total), None))
+            details_rows.append(
+                (self.DOWN_TOTAL_TEXT, displaytext.size_string(self.data.down_total), None))
+            details_rows.append((None, None, None))
+            details_rows.append(
+                (self.UP_DOWN_RATIO_TEXT, "%0.2f" % self.data.up_down_ratio, None))
 
         if details_rows:
             details_box = self.create_pseudo_table(layout, details_rows)
@@ -696,7 +705,16 @@ class ItemRenderer(widgetset.CustomCellRenderer):
         layout.set_font(0.85)
         if self.data.downloaded:
             if self.data.is_playable:
-                button = cellpack.Hotspot('play', self.play_button)
+                if ((app.playback_manager.get_playing_item()
+                     and app.playback_manager.get_playing_item().id == self.data.id)):
+                    if app.playback_manager.is_paused:
+                        button = cellpack.Hotspot('play_pause',
+                                                  self.play_button)
+                    else:
+                        button = cellpack.Hotspot('play_pause',
+                                                  self.pause_playback_button)
+                else:
+                    button = cellpack.Hotspot('play', self.play_button)
             else:
                 button = self._make_button(layout, self.REVEAL_IN_TEXT,
                         'show_local_file')
@@ -843,8 +861,8 @@ class ItemRenderer(widgetset.CustomCellRenderer):
 
         outer_hbox.pack(vbox, expand=True)
         outer_vbox.pack(outer_hbox)
-        outer_hbox.pack_space(12)
         if self.show_details:
+            outer_hbox.pack_space(12)
             outer_vbox.pack_end(self.pack_flap(layout))
         return self.add_background(outer_vbox)
 
