@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,10 +39,11 @@ _gtcache = None
 codeset = None # The default codeset of our locale (always lower case)
 
 def init():
+    import logging
     global _gtcache
     global codeset
     _gtcache = {}
-    if not miro.plat.utils.localeInitialized:
+    if not miro.plat.utils.locale_initialized():
         raise Exception, "locale not initialized"
 
     # try to set the locale to the platform default, but if that fails
@@ -50,7 +51,6 @@ def init():
     try:
         locale.setlocale(locale.LC_ALL, '')
     except locale.Error:
-        import logging
         logging.warn("gtcache.init: setlocale failed.  setting locale to 'C'")
         locale.setlocale(locale.LC_ALL, 'C')
 
@@ -58,7 +58,6 @@ def init():
     try:
         codeset = locale.getlocale()[1]
     except ValueError:
-        import logging
         logging.warn("gtcache.init: getlocale failed.  setting locale to 'C'")
         locale.setlocale(locale.LC_ALL, "C")
         codeset = locale.getlocale()[1]
