@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,7 +53,8 @@ from miro.clock import clock
 from miro import httpauth
 from miro import config
 from miro import prefs
-from miro.download_utils import cleanFilename, parseURL, defaultPort, getFileURLPath, filenameFromURL
+from miro.download_utils import (clean_filename, parse_url, default_port, 
+                                 get_file_url_path, filename_from_url)
 from miro.xhtmltools import url_encode_dict, multipart_encode
 from miro import eventloop
 from miro import util
@@ -69,6 +70,17 @@ SOCKET_READ_TIMEOUT = 60
 SOCKET_INITIAL_READ_TIMEOUT = 30
 SOCKET_CONNECT_TIMEOUT = 15
 
+# socket.ssl is deprecated as of Python 2.6, so we use socket_ssl for
+# pre Python 2.6 and ssl.wrap_socket for Python 2.6 and later.
+try:
+    import ssl
+    ssl.wrap_socket
+    def convert_to_ssl(sock):
+        return ssl.wrap_socket(sock)
+except (ImportError, AttributeError):
+    def convert_to_ssl(sock):
+        return socket.ssl(sock)
+
 def user_agent():
     return "%s/%s (%s; %s)" % (config.get(prefs.SHORT_APP_NAME),
             config.get(prefs.APP_VERSION),
@@ -97,7 +109,8 @@ class NetworkError(Exception):
 
     def __str__(self):
         return "%s: %s -- %s" % (self.__class__,
-                self.getFriendlyDescription(), self.getLongDescription())
+                util.stringify(self.getFriendlyDescription()), 
+                util.stringify(self.getLongDescription()))
 
 class ConnectionError(NetworkError):
     def __init__(self, errorMessage):
@@ -208,7 +221,7 @@ def get_cookie_expiration_date(val):
         except ValueError, ve:
             pass
 
-    print "DTV: Warning: Can't process cookie expiration: '%s'" % val
+    logging.warning("DTV: Warning: Can't process cookie expiration: '%s'", val)
     return 0
 
 
@@ -228,6 +241,13 @@ class NetworkBuffer(object):
     def _mergeChunks(self):
         self.chunks = [''.join(self.chunks)]
 
+    def has_data(self):
+        return self.length > 0
+
+    def discard_data(self):
+        self.chunks = []
+        self.length = 0
+
     def read(self, size=None):
         """Read at most size bytes from the data that has been added to the
         buffer.  """
@@ -468,8 +488,8 @@ class AsyncSocket(object):
         else:
             expectedErrors = (errno.ECONNREFUSED, errno.ECONNRESET)
         if code not in expectedErrors:
-            print "WARNING, got unexpected error during %s" % operation
-            print "%s: %s" % (errno.errorcode.get(code), msg)
+            logging.warning("WARNING, got unexpected error during %s", operation)
+            logging.warning("%s: %s", errno.errorcode.get(code), msg)
         self.handleEarlyClose(operation)
 
     def onWriteReady(self):
@@ -504,10 +524,10 @@ class AsyncSocket(object):
             # read.
             self.memoryErrors += 1
             if self.memoryErrors > self.MEMORY_ERROR_LIMIT:
-                print "ERROR: Too many MemoryErrors on %s" % self
+                logging.error("ERROR: Too many MemoryErrors on %s", self)
                 self.handleEarlyClose('read')
             else:
-                print "WARNING: Memory error while reading from %s" % self
+                logging.warning("WARNING: Memory error while reading from %s", self)
         else:
             self.memoryErrors = 0
             self.handleReadData(data)
@@ -538,18 +558,20 @@ class AsyncSSLStream(AsyncSocket):
     def openConnection(self, host, port, callback, errback, disableReadTimeout=None):
         def onSocketOpen(self):
             self.socket.setblocking(1)
-            eventloop.callInThread(onSSLOpen, handleSSLError, socket.ssl,
+            eventloop.callInThread(onSSLOpen, handleSSLError, convert_to_ssl,
                                    "AsyncSSL onSocketOpen()",
                                    self.socket)
         def onSSLOpen(ssl):
             if self.socket is None:
-                # the connection was closed while we were calling socket.ssl
+                # the connection was closed while we were calling
+                # convert_to_ssl
                 return
             self.socket.setblocking(0)
             self.ssl = ssl
             # finally we can call the actuall callback
             callback(self)
         def handleSSLError(error):
+            logging.error("handleSSLError: %r", error)
             errback(SSLConnectionError())
         super(AsyncSSLStream, self).openConnection(host, port, onSocketOpen,
                 errback, disableReadTimeout)
@@ -637,21 +659,24 @@ class ProxiedAsyncSSLStream(AsyncSSLStream):
                     data += self.socket.recv(1)
                 data = data.split("\r\n")
                 if -1 == data[0].find(' 200 '):
-                    eventloop.addIdle(lambda :handleSSLError(NetworkError(data[0])),"Network Error")
+                    eventloop.addIdle(lambda :handleSSLError(
+                        NetworkError(data[0])), "Network Error")
                 else:
-                    return socket.ssl(self.socket)
+                    return convert_to_ssl(self.socket)
             except socket.error, (code, msg):
                 handleSSLError(msg)
 
         def onSSLOpen(ssl):
             if self.socket is None or ssl is None:
-                # the connection was closed while we were calling socket.ssl
+                # the connection was closed while we were calling
+                # convert_to_ssl
                 return
             self.socket.setblocking(0)
             self.ssl = ssl
             # finally we can call the actuall callback
             callback(self)
         def handleSSLError(error):
+            logging.error("handleSSLError: %r", error)
             errback(SSLConnectionError())
         proxy_host = config.get(prefs.HTTP_PROXY_HOST)
         proxy_port = config.get(prefs.HTTP_PROXY_PORT)
@@ -700,6 +725,7 @@ class ConnectionHandler(object):
         if self.stream.isOpen():
             self.stream.closeConnection()
         self.changeState('closed')
+        self.buffer.discard_data()
 
     def sendData(self, data, callback=None):
         self.stream.sendData(data, callback)
@@ -828,13 +854,17 @@ class HTTPConnection(ConnectionHandler):
         if not self.canSendRequest():
             raise NetworkError(_("Unknown"), 
                     _("Internal Error: Not ready to send"))
+        if self.state == 'ready' and self.buffer.has_data():
+            logging.warning("Discarding extra data after request for %s",
+                    host)
+            self.buffer.discard_data()
 
         if headers is None:
             headers = {}
         else:
             headers = headers.copy()
         headers['Host'] = host.encode('idna')
-        if port != defaultPort(self.scheme):
+        if port != default_port(self.scheme):
             headers['Host'] += ':%d' % port
         headers['Accept-Encoding'] = 'identity'
 
@@ -1050,7 +1080,7 @@ class HTTPConnection(ConnectionHandler):
         value = value.strip()
         header = header.lstrip().lower()
         if value == '':
-            print "DTV: Warning: Bad Header from %s://%s:%s%s (%s)" % (self.scheme, self.host, self.port, self.path, line)
+            logging.debug("DTV: Warning: Bad Header from %s://%s:%s%s (%s)", self.scheme, self.host, self.port, self.path, line)
         if header not in self.headers:
             self.headers[header] = value
         else:
@@ -1153,7 +1183,7 @@ class HTTPConnection(ConnectionHandler):
 
     # This needs to be in an idle so that the connection is added
     # to the "active" list before the open callback happens --NN
-    @eventloop.asIdle
+    @eventloop.as_idle
     def maybeSendReadyCallback(self):
         if (self.readyCallback and self.canSendRequest() and not
                 self.sentReadyCallback):
@@ -1162,9 +1192,10 @@ class HTTPConnection(ConnectionHandler):
         
     def handleClose(self, type):
         oldState = self.state
+        last_data = self.buffer.read()
         self.closeConnection()
         if oldState == 'response-body' and self.contentLength is None:
-            self.body = self.buffer.read()
+            self.body = last_data
             self.finishRequest()
         elif self.stream.timedOut:
             self.errback(ConnectionTimeout(self.host))
@@ -1253,8 +1284,8 @@ class HTTPConnectionPool(object):
             conns['free'].remove(conn)
             self.freeConnectionCount -= 1
         else:
-            logging.warn("_onConnectionClosed called with connection not "
-                    "in either queue")
+            logging.warning("_onConnectionClosed called with connection not "
+                            "in either queue")
         self.runPendingRequests()
 
     def _onConnectionReady(self, conn):
@@ -1263,14 +1294,14 @@ class HTTPConnectionPool(object):
             conns['active'].remove(conn)
             self.activeConnectionCount -= 1
         else:
-            logging.warn("_onConnectionReady called with connection not "
-                    "in the active queue")
+            logging.warning("_onConnectionReady called with connection not "
+                            "in the active queue")
         if conn not in conns['free']:
             conns['free'].add(conn)
             self.freeConnectionCount += 1
         else:
-            logging.warn("_onConnectionReady called with connection already "
-                    "in the free queue")
+            logging.warning("_onConnectionReady called with connection already "
+                            "in the free queue")
         self.runPendingRequests()
 
     def addRequest(self, callback, errback, requestStartCallback,
@@ -1280,7 +1311,7 @@ class HTTPConnectionPool(object):
         have a free connection, otherwise it will be queued.
         """
         proxy_host = proxy_port = None
-        scheme, host, port, path = parseURL(url)
+        scheme, host, port, path = parse_url(url)
         if scheme not in ['http', 'https'] or host == '' or path == '':
             errback (MalformedURL(url))
             return
@@ -1502,7 +1533,7 @@ class HTTPClient(object):
 
     def dropStaleCookies(self):
         """Remove cookies that have expired or are invalid for this URL"""
-        scheme, host, port, path = parseURL(self.url)
+        scheme, host, port, path = parse_url(self.url)
         temp = {}
         for name in self.cookies:
             if self.isValidCookie(self.cookies[name], scheme, host, port, path):
@@ -1561,7 +1592,7 @@ class HTTPClient(object):
         self.willHandleResponse = False
         self.gotBadStatusCode = False
         if 'Authorization' not in self.headers:
-            scheme, host, port, path = parseURL(self.redirectedURL)
+            scheme, host, port, path = parse_url(self.redirectedURL)
             def callback(authHeader):
                 if self.cancelled:
                     return
@@ -1596,7 +1627,7 @@ class HTTPClient(object):
 
     def callbackIntercept(self, response):
         if self.cancelled:
-            print "WARNING: Callback on a cancelled request for %s" % self.url
+            logging.warning("WARNING: Callback on a cancelled request for %s", self.url)
             traceback.print_stack()
             return
         if self.shouldRedirect(response):
@@ -1669,7 +1700,7 @@ class HTTPClient(object):
         except (SystemExit, KeyboardInterrupt):
             raise
         except:
-            print "ERROR in getCookiesFromResponse()"
+            logging.error("ERROR in getCookiesFromResponse()")
             traceback.print_exc()
         return response
 
@@ -1687,7 +1718,7 @@ class HTTPClient(object):
         cookies = {}
         cookieStrings = []
         if response.has_key('set-cookie') or response.has_key('set-cookie2'):
-            scheme, host, port, path = parseURL(self.redirectedURL)
+            scheme, host, port, path = parse_url(self.redirectedURL)
 
             # Split header into cookie strings, respecting commas in
             # the middle of stuff
@@ -1795,8 +1826,8 @@ class HTTPClient(object):
         else:
             filename = self.findValueFromHeader(disposition, 'filename')
             if filename is not None:
-                return cleanFilename(filename)
-        return filenameFromURL(util.unicodify(response['redirected-url']), clean=True)
+                return clean_filename(filename)
+        return filename_from_url(util.unicodify(response['redirected-url']), clean=True)
 
     def getCharsetFromResponse(self, response):
         try:
@@ -1861,10 +1892,12 @@ def grabURL(url, callback, errback, headerCallback=None,
         bodyDataCallback=None, method="GET", start=0, etag=None,
         modified=None, cookies=None, postVariables=None, postFiles=None,
         defaultMimeType='application/octet-stream', clientClass=HTTPClient):
+    if url is None:
+        errback(MalformedURL(url))
     if cookies == None:
         cookies = {}
     if url.startswith("file://"):
-        path = getFileURLPath(url)
+        path = get_file_url_path(url)
         try:
             f = file(path)
         except EnvironmentError:
@@ -1884,7 +1917,8 @@ def grabURL(url, callback, errback, headerCallback=None,
                            })
     else:
         client = clientClass(url, callback, errback, headerCallback,
-            bodyDataCallback, method, start, etag, modified, cookies, postVariables, postFiles)
+                             bodyDataCallback, method, start, etag,
+                             modified, cookies, postVariables, postFiles)
         client.startRequest()
         return client
 
