@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,10 +30,10 @@ import os
 import logging
 
 from miro import httpclient
-from fasttypes import LinkedList
+from datastructures import Fifo
 from miro import eventloop
 from miro.database import DDBObject, ObjectNotFoundError
-from miro.download_utils import nextFreeFilename, getFileURLPath
+from miro.download_utils import next_free_filename, get_file_url_path
 from miro.util import unicodify
 from miro.plat.utils import unicodeToFilename
 from miro import config
@@ -45,12 +45,12 @@ RUNNING_MAX = 3
 
 class IconCacheUpdater:
     def __init__(self):
-        self.idle = LinkedList()
-        self.vital = LinkedList()
+        self.idle = Fifo()
+        self.vital = Fifo()
         self.runningCount = 0
         self.inShutdown = False
 
-    @eventloop.asIdle
+    @eventloop.as_idle
     def request_update(self, item, is_vital=False):
         if is_vital:
             item.dbItem.confirm_db_thread()
@@ -62,9 +62,9 @@ class IconCacheUpdater:
             self.runningCount += 1
         else:
             if is_vital:
-                self.vital.prepend(item)
+                self.vital.enqueue(item)
             else:
-                self.idle.prepend(item)
+                self.idle.enqueue(item)
 
     def update_finished(self):
         if self.inShutdown:
@@ -72,20 +72,20 @@ class IconCacheUpdater:
             return
 
         if len(self.vital) > 0:
-            item = self.vital.pop()
+            item = self.vital.dequeue()
         elif len(self.idle) > 0:
-            item = self.idle.pop()
+            item = self.idle.dequeue()
         else:
             self.runningCount -= 1
             return
 
         eventloop.addIdle(item.request_icon, "Icon Request")
 
-    @eventloop.asIdle
+    @eventloop.as_idle
     def clear_vital(self):
-        self.vital = LinkedList()
+        self.vital = Fifo()
 
-    @eventloop.asIdle
+    @eventloop.as_idle
     def shutdown(self):
         self.inShutdown = True
 
@@ -113,14 +113,14 @@ class IconCache(DDBObject):
 
     @classmethod
     def all_filenames(cls):
-        return [r[0] for r in cls.select("filename", 'filename IS NOT NULL')]
+        return [r[0] for r in cls.select(["filename"], 'filename IS NOT NULL')]
 
-    def icon_changed(self, needsSave=True):
-        self.signal_change(needsSave=needsSave)
+    def icon_changed(self, needs_save=True):
+        self.signal_change(needs_save=needs_save)
         if hasattr(self.dbItem, 'icon_changed'):
             self.dbItem.icon_changed()
         else:
-            self.dbItem.signal_change(needsSave=False)
+            self.dbItem.signal_change(needs_save=False)
 
     def remove(self):
         self.removed = True
@@ -174,7 +174,7 @@ class IconCache(DDBObject):
             iconCacheUpdater.update_finished()
             return
 
-        needsSave = False
+        needs_save = False
         needsChange = False
 
         if info == None or (info['status'] != 304 and info['status'] != 200):
@@ -205,7 +205,7 @@ class IconCache(DDBObject):
                 else:
                     tmp_filename = os.path.join(cachedir, info["filename"]) + ".part"
 
-                tmp_filename = nextFreeFilename(tmp_filename)
+                tmp_filename = next_free_filename(tmp_filename)
                 output = fileutil.open_file(tmp_filename, 'wb')
                 output.write(info["body"])
                 output.close()
@@ -228,30 +228,30 @@ class IconCache(DDBObject):
             self.filename = u'.'.join(parts)
             self.filename = unicodeToFilename(self.filename, cachedir)
             self.filename = os.path.join(cachedir, self.filename)
-            self.filename = nextFreeFilename(self.filename)
-            needsSave = True
+            self.filename = next_free_filename(self.filename)
+            needs_save = True
 
             try:
                 fileutil.rename(tmp_filename, self.filename)
             except OSError:
                 self.filename = None
-                needsSave = True
+                needs_save = True
 
             etag = unicodify(info.get("etag"))
             modified = unicodify(info.get("modified"))
 
             if self.etag != etag:
-                needsSave = True
+                needs_save = True
                 self.etag = etag
             if self.modified != modified:
-                needsSave = True
+                needs_save = True
                 self.modified = modified
             if self.url != url:
-                needsSave = True
+                needs_save = True
                 self.url = url
         finally:
             if needsChange:
-                self.icon_changed(needsSave=needsSave)
+                self.icon_changed(needs_save=needs_save)
             self.updating = False
             if self.needsUpdate:
                 self.needsUpdate = False
@@ -310,7 +310,7 @@ class IconCache(DDBObject):
     def get_filename(self):
         self.dbItem.confirm_db_thread()
         if self.url and self.url.startswith(u"file://"):
-            return getFileURLPath(self.url)
+            return get_file_url_path(self.url)
         elif self.url and self.url.startswith(u"/"):
             return unicodeToFilename(self.url)
         else:
