@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -116,7 +116,7 @@ class BackendMessage(Message):
         try:
             handler = self.handler
         except AttributeError:
-            logging.warn("No handler for backend messages (%s)", repr(self))
+            logging.warn("No handler for backend messages")
         else:
             handler.handle(self)
 
@@ -127,7 +127,7 @@ class FrontendMessage(Message):
         try:
             handler = self.handler
         except AttributeError:
-            logging.warn("No handler for frontend messages (%s)", repr(self))
+            logging.warn("No handler for frontend messages")
         else:
             handler.handle(self)
 
@@ -358,7 +358,7 @@ class RenameObject(BackendMessage):
     def __init__(self, type, id, new_name):
         self.type = type
         self.id = id
-        self.new_name = util.toUni(new_name)
+        self.new_name = util.to_uni(new_name)
 
 class UpdateFeed(BackendMessage):
     """Updates a feed.
@@ -397,6 +397,13 @@ class SetItemResumeTime(BackendMessage):
         self.id = id
         self.resume_time = time
 
+class SetItemMediaType(BackendMessage):
+    """Adds a list of videos to a playlist.
+    """
+    def __init__(self, media_type, video_ids):
+        self.media_type = media_type
+        self.video_ids = video_ids
+
 class UpdateAllFeeds(BackendMessage):
     """Updates all feeds.
     """
@@ -438,13 +445,13 @@ class NewGuide(BackendMessage):
     """Create a new channel guide.
     """
     def __init__(self, url):
-        self.url = util.toUni(url)
+        self.url = util.to_uni(url)
 
 class NewFeed(BackendMessage):
     """Creates a new feed.
     """
     def __init__(self, url, section=u"video"):
-        self.url = util.toUni(url)
+        self.url = util.to_uni(url)
         self.section = section
 
 class NewFeedSearchFeed(BackendMessage):
@@ -488,14 +495,14 @@ class NewPlaylist(BackendMessage):
     """Create a new playlist.
     """
     def __init__(self, name, ids):
-        self.name = util.toUni(name)
+        self.name = util.to_uni(name)
         self.ids = ids
 
 class NewFeedFolder(BackendMessage):
     """Create a new feed folder.
     """
     def __init__(self, name, section, child_feed_ids):
-        self.name = util.toUni(name)
+        self.name = util.to_uni(name)
         self.section = section
         self.child_feed_ids = child_feed_ids
 
@@ -503,7 +510,7 @@ class NewPlaylistFolder(BackendMessage):
     """Create a new playlist folder.
     """
     def __init__(self, name, child_playlist_ids):
-        self.name = util.toUni(name)
+        self.name = util.to_uni(name)
         self.child_playlist_ids = child_playlist_ids
 
 class ChangeMoviesDirectory(BackendMessage):
@@ -542,7 +549,7 @@ class DownloadURL(BackendMessage):
     :param metadata: dict of name/value pairs to include in the item.
     """
     def __init__(self, url, handle_unknown_callback=None, metadata=None):
-        self.url = util.toUni(url)
+        self.url = util.to_uni(url)
         self.handle_unknown_callback = handle_unknown_callback
         self.metadata = metadata
 
@@ -663,12 +670,12 @@ class DeleteVideo(BackendMessage):
     def __repr__(self):
         return BackendMessage.__repr__(self) + (", id: %s" % self.id)
 
-class RenameVideo(BackendMessage):
-    """Renames the video.
+class EditItem(BackendMessage):
+    """Changes a bunch of things on an item.
     """
-    def __init__(self, id, new_name):
-        self.id = id
-        self.new_name = new_name
+    def __init__(self, item_id, change_dict):
+        self.item_id = item_id
+        self.change_dict = change_dict
 
 class RevertFeedTitle(BackendMessage):
     """Reverts the feed's title back to the original.
@@ -676,12 +683,6 @@ class RevertFeedTitle(BackendMessage):
     def __init__(self, id):
         self.id = id
 
-class RevertItemTitle(BackendMessage):
-    """Reverts the item's title back to the original.
-    """
-    def __init__(self, id):
-        self.id = id
-
 class PlayAllUnwatched(BackendMessage):
     """Figures out all the unwatched items and plays them.
     """
@@ -916,7 +917,7 @@ class GuideInfo(object):
         self.name = guide.get_title()
         self.id = guide.id
         self.url = guide.get_url()
-        self.default = guide.get_default()
+        self.default = guide.is_default()
         self.allowed_urls = guide.allowedURLs
         self.favicon = guide.get_favicon_path()
         self.faviconIsDefault = not (guide.icon_cache and
@@ -951,6 +952,7 @@ class ItemInfo(object):
     :param video_watched: has the user watched the video for the item?
     :param video_path: the file path to the video for this item (or None)
     :param file_type: type of the downloaded file (video/audio/other)
+    :param media_type_checked: has the movie data util checked file_type?
     :param seeding_status: Torrent seeding status ('seeding', 'stopped',
                            or None)
     :param thumbnail: path to the thumbnail for this file
@@ -975,10 +977,10 @@ class ItemInfo(object):
     :param down_rate: (Torrent only) how fast we're downloading data
     :param up_total: (Torrent only) total amount we've uploaded
     :param down_total: (Torrent only) total amount we've downloaded
+    :param up_down_ratio: (Torrent only) ratio of uploaded to downloaded
     """
     def __init__(self, item):
         self.name = item.get_title()
-        self.has_original_name = item.has_original_title()
         self.id = item.id
         self.feed_id = item.feed_id
         self.feed_name = item.get_source()
@@ -1017,6 +1019,7 @@ class ItemInfo(object):
         else:
             self.children = []
         self.file_type = item.file_type
+        self.media_type_checked = item.media_type_checked
         self.seeding_status = item.torrent_seeding_status()
         self.mime_type = item.enclosure_type
         self.file_url = item.url
@@ -1031,6 +1034,7 @@ class ItemInfo(object):
         ## Torrent-specific stuff
         self.leechers = self.seeders = self.up_rate = None
         self.down_rate = self.up_total = self.down_total = None
+        self.up_down_ratio = 0.0
         if item.looks_like_torrent() and hasattr(item.downloader, 'status'):
             status = item.downloader.status
             if item.is_transferring():
@@ -1043,6 +1047,10 @@ class ItemInfo(object):
             # gettorrentdetailsfinished & gettorrentdetails
             self.up_total = status.get('uploaded', 0)
             self.down_total = status.get('currentSize', 0)
+            if self.down_total <= 0:
+                self.up_down_ratio = 0.0
+            else:
+                self.up_down_ratio = self.up_total * 1.0 / self.down_total
 
 class DownloadInfo(object):
     """Tracks the download state of an item.
@@ -1060,18 +1068,18 @@ class DownloadInfo(object):
     """
     def __init__(self, downloader):
         self.downloaded_size = downloader.get_current_size()
-        self.rate = downloader.getRate()
+        self.rate = downloader.get_rate()
         self.state = downloader.get_state()
         self.startup_activity = downloader.get_startup_activity()
-        self.finished = downloader.isFinished()
+        self.finished = downloader.is_finished()
         self.torrent = (downloader.get_type() == 'bittorrent')
         if self.state == 'failed':
-            self.reason_failed = downloader.getReasonFailed()
-            self.short_reason_failed = downloader.getShortReasonFailed()
+            self.reason_failed = downloader.get_reason_failed()
+            self.short_reason_failed = downloader.get_short_reason_failed()
         else:
             self.reason_failed = u""
             self.short_reason_failed = u""
-        self.eta = downloader.getETA()
+        self.eta = downloader.get_eta()
 
 class PendingDownloadInfo(DownloadInfo):
     """DownloadInfo object for pending downloads (downloads queued,
@@ -1113,7 +1121,7 @@ class GuideList(FrontendMessage):
             # for it to have a default channel guide persisted, but when you
             # set the channel guide via the DTV_CHANNELGUIDE_URL, then there's
             # no default guide.  So we generate one here.  Bug #11027.
-            cg = guide.ChannelGuide(util.toUni(config.get(prefs.CHANNEL_GUIDE_URL)))
+            cg = guide.ChannelGuide(util.to_uni(config.get(prefs.CHANNEL_GUIDE_URL)))
             cg_info = GuideInfo(cg)
             self.default_guide = [cg_info]
         elif len(self.default_guide) > 1:
