@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -71,11 +71,11 @@ from miro import messages
 from miro import schema
 from miro import prefs
 from miro import util
-from miro.download_utils import nextFreeFilename
+from miro.download_utils import next_free_filename
 from miro.gtcache import gettext as _
 from miro.plat.utils import FilenameType, filenameToUnicode
 
-class UpgradeDiskSpaceError(Exception):
+class UpgradeError(Exception):
     """While upgrading the database, we ran out of disk space."""
     pass
 
@@ -98,6 +98,18 @@ _sqlite_type_map = {
 
 VERSION_KEY = "Democracy Version"
 
+def split_values_for_sqlite(value_list):
+    """Split a list of values into chunks that SQL can handle.
+
+    The cursor.execute() method can only handle 999 values at once, this
+    method splits long lists into chunks where each chunk has is safe to feed
+    to sqlite.
+    """
+    CHUNK_SIZE = 990 # use 990 just to be on the safe side.
+    for start in xrange(0, len(value_list), CHUNK_SIZE):
+        yield value_list[start:start+CHUNK_SIZE]
+
+
 class LiveStorage:
     """Handles the storage of DDBObjects.
 
@@ -127,6 +139,7 @@ class LiveStorage:
             logging.info("sqlite3 has no version attribute.")
 
         db_existed = os.path.exists(path)
+        self.raise_load_errors = False # only gets set in unittests
         self._dc = None
         self._query_times = {}
         self.path = path
@@ -135,23 +148,30 @@ class LiveStorage:
         self._object_schemas = object_schemas
         self._schema_version = schema_version
         self._schema_map = {}
+        self._schema_column_map = {}
         self._all_schemas = []
         self._object_map = {} # maps object id -> DDBObjects in memory
         self._ids_loaded = set()
+        self._statements_in_transaction = []
+        eventloop.connect("event-finished", self.on_event_finished)
         for oschema in object_schemas:
             self._all_schemas.append(oschema)
             for klass in oschema.ddb_object_classes():
                 self._schema_map[klass] = oschema
                 for field_name, schema_item in oschema.fields:
                     klass.track_attribute_changes(field_name)
+            for name, schema_item in oschema.fields:
+                self._schema_column_map[oschema, name] = schema_item
         self._converter = SQLiteConverter()
 
         if not db_existed:
             self._init_database()
 
-    def open_connection(self):            
-        logging.info("opening database %s", self.path)
-        self.connection = sqlite3.connect(self.path,
+    def open_connection(self, path=None):
+        if path is None:
+            path = self.path
+        logging.info("opening database %s", path)
+        self.connection = sqlite3.connect(path,
                 isolation_level=None,
                 detect_types=sqlite3.PARSE_DECLTYPES)
         self.cursor = self.connection.cursor()
@@ -161,6 +181,7 @@ class LiveStorage:
         if self._dc:
             self._dc.cancel()
             self._dc = None
+        self.finish_transaction()
 
         # the unittests run in memory and vacuum causes a segfault if
         # the db is in memory.
@@ -179,17 +200,40 @@ class LiveStorage:
         except (KeyError, SystemError,
                 databaseupgrade.DatabaseTooNewError):
             raise
-        except sqlite3.OperationalError, e:
-            logging.exception('OperationalError when upgrading database: %s',
-                    e)
-            raise UpgradeDiskSpaceError()
-        except UpgradeDiskSpaceError:
-            raise
-        except:
-            self._handle_load_error("Error upgrading database")
+        except Exception, e:
+            logging.exception('error when upgrading database: %s', e)
+            self._handle_upgrade_error()
 
-    def _backup_database(self, ver):
-        """Backs up the database file.
+    def _handle_upgrade_error(self):
+        title = _("%(appname)s database upgrade failed",
+                  {"appname": config.get(prefs.SHORT_APP_NAME)})
+        description = _(
+            "We're sorry, %(appname)s was unable to upgrade your database "
+            "due to errors.\n\n"
+            "Check to see if your disk is full.  If it is full, then quit "
+            "%(appname)s, free up some space, and start %(appname)s "
+            "again.\n\n"
+            "If your disk is not full, help us understand the problem by "
+            "quitting, then reporting a bug at bugzilla.pculture.org\n\n"
+
+            "Finally, you can start fresh and your damaged database will be "
+            "removed, but you will have to re-add your feeds and media "
+            "files.", {"appname": config.get(prefs.SHORT_APP_NAME)}
+            )
+        d = dialogs.ChoiceDialog(title, description,
+                dialogs.BUTTON_QUIT, dialogs.BUTTON_START_FRESH)
+        choice = d.run_blocking()
+        if choice == dialogs.BUTTON_START_FRESH:
+            self._handle_load_error("Error upgrading database")
+            self.startup_version = self.current_version = self._get_version()
+        else:
+            raise UpgradeError()
+
+    def _change_database_file(self, ver):
+        """Switches the sqlitedb file that we have open
+
+        This is called before doing a database upgrade.  This allows us to
+        keep the database file unmodified in case the upgrade fails.
 
         :param ver: the current version (as string)
         """
@@ -197,17 +241,27 @@ class LiveStorage:
         # close database
         self.close()
 
-        # copy file over
-        try:
-            shutil.copyfile(self.path, "%s_backup_%s" % (self.path, ver))
-        except IOError, e:
-            logging.exception('Error when backing up database')
+        save_name = self._find_unused_db_name("upgrading_database_%s" % ver)
+        path = os.path.join(os.path.dirname(self.path), save_name)
+        shutil.copyfile(self.path, path)
+        self.open_connection(path)
+        self._changed_db_path = path
 
-        # re-open database
+    def _change_database_file_back(self):
+        """Switches the sqlitedb file back to our regular one.
+
+        This works together with _change_database_file() to handle database
+        upgrades.  Once the upgrade is finished, this method copies the
+        database we were using to the normal place, and switches our sqlite
+        connection to use that file
+        """
+        self.close()
+        shutil.move(self._changed_db_path, self.path)
         self.open_connection()
+        del self._changed_db_path
 
     def _upgrade_database(self):
-        current_version = self._get_variable(VERSION_KEY)
+        self.startup_version = current_version = self._get_version()
 
         if current_version > self._schema_version:
             msg = _("Database was created by a newer version of Miro " +
@@ -221,20 +275,22 @@ class LiveStorage:
                 self._upgrade_20_database()
                 # need to pull the variable again here because
                 # _upgrade_20_database will have done an upgrade
-                current_version = self._get_variable(VERSION_KEY)
-                self._backup_database(current_version)
+                current_version = self._get_version()
+                self._change_database_file(current_version)
                 databaseupgrade.new_style_upgrade(self.cursor,
                                                   current_version,
                                                   self._schema_version)
                 self._set_version()
+                self._change_database_file_back()
             finally:
                 dbupgradeprogress.upgrade_end()
+        self.current_version = self._schema_version
 
     def _upgrade_20_database(self):
         self.cursor.execute("SELECT COUNT(*) FROM sqlite_master "
                 "WHERE type='table' and name = 'dtv_objects'")
         if self.cursor.fetchone()[0] > 0:
-            current_version = self._get_variable(VERSION_KEY)
+            current_version = self._get_version()
             if current_version >= 80:
                 # we have a dtv_objects table, but we also have a database
                 # that's been converted to the new-style.  What happened was
@@ -245,13 +301,14 @@ class LiveStorage:
                 self.cursor.execute("DROP TABLE dtv_objects")
             else:
                 # Need to update an old-style database
-                self._backup_database("pre80")
+                self._change_database_file("pre80")
                 dbupgradeprogress.doing_20_upgrade()
 
                 if util.chatter:
                     logging.info("converting pre 2.1 database")
                 convert20database.convert(self.cursor)
                 self._set_version(80)
+                self._change_database_file_back()
 
     def _get_variable(self, name):
         self.cursor.execute("SELECT serialized_value FROM dtv_variables "
@@ -279,14 +336,14 @@ class LiveStorage:
         del self._object_map[obj.id]
         self._ids_loaded.remove(obj.id)
 
-    def insert_obj(self, obj):
-        """Add a new DDBObject to disk."""
+    def _insert_sql_for_schema(self, obj_schema):
+        return "INSERT INTO %s (%s) VALUES(%s)" % (obj_schema.table_name,
+                ', '.join(name for name, schema_item in obj_schema.fields),
+                ', '.join('?' for i in xrange(len(obj_schema.fields))))
 
-        obj_schema = self._schema_map[obj.__class__]
-        column_names = []
+    def _values_for_obj(self, obj_schema, obj):
         values = []
         for name, schema_item in obj_schema.fields:
-            column_names.append(name)
             value = getattr(obj, name)
             try:
                 schema_item.validate(value)
@@ -296,11 +353,35 @@ class LiveStorage:
                 raise
             values.append(self._converter.to_sql(obj_schema, name,
                 schema_item, value))
-        sql = "INSERT INTO %s (%s) VALUES(%s)" % (obj_schema.table_name,
-                ', '.join(column_names),
-                ', '.join('?' for i in xrange(len(column_names))))
+        return values
+
+    def insert_obj(self, obj):
+        """Add a new DDBObject to disk."""
+
+        obj_schema = self._schema_map[obj.__class__]
+        values = self._values_for_obj(obj_schema, obj)
+        sql = self._insert_sql_for_schema(obj_schema)
         self._execute(sql, values, is_update=True)
-        self.remember_object(obj)
+        obj.reset_changed_attributes()
+
+    def bulk_insert(self, objects):
+        """Insert a list of objects in one go.
+
+        Throws a ValueError if the objects don't all use the same database
+        table.
+        """
+        if len(objects) == 0:
+            return
+        obj_schema = self._schema_map[objects[0].__class__]
+        value_list = []
+        for obj in objects:
+            if obj_schema != self._schema_map[obj.__class__]:
+                raise ValueError("Incompatible types for bulk insert")
+            value_list.append(self._values_for_obj(obj_schema, obj))
+        sql = self._insert_sql_for_schema(obj_schema)
+        self._execute(sql, value_list, is_update=True, many=True)
+        for obj in objects:
+            obj.reset_changed_attributes()
 
     def update_obj(self, obj):
         """Update a DDBObject on disk."""
@@ -326,8 +407,11 @@ class LiveStorage:
         if values:
             sql = "UPDATE %s SET %s WHERE id=%s" % (obj_schema.table_name,
                     ', '.join(setters), obj.id)
-            self._execute(sql, values)
-        self.remember_object(obj)
+            self._execute(sql, values, is_update=True)
+            if (self.cursor.rowcount != 1 and not
+                    self._quitting_from_operational_error):
+                raise AssertionError("update_obj changed %s rows" %
+                        self.cursor.rowcount)
 
     def remove_obj(self, obj):
         """Remove a DDBObject from disk."""
@@ -337,6 +421,29 @@ class LiveStorage:
         self._execute(sql, (obj.id,), is_update=True)
         self.forget_object(obj)
 
+    def bulk_remove(self, objects):
+        """Remove a list of objects in one go.
+
+        Throws a ValueError if the objects don't all use the same database
+        table.
+        """
+
+        if len(objects) == 0:
+            return
+        obj_schema = self._schema_map[objects[0].__class__]
+        for obj in objects:
+            if obj_schema != self._schema_map[obj.__class__]:
+                raise ValueError("Incompatible types for bulk remove")
+        # we can only feed sqlite so many variables at once, send it chunks of
+        # 900 ids at once
+        for objects_chunk in split_values_for_sqlite(objects):
+            commas = ','.join('?' for x in xrange(len(objects_chunk)))
+            sql = "DELETE FROM %s WHERE id IN (%s)" % (obj_schema.table_name,
+                    commas)
+            self._execute(sql, [o.id for o in objects_chunk], is_update=True)
+        for obj in objects:
+            self.forget_object(obj)
+
     def get_last_id(self):
         try:
             return self._get_last_id()
@@ -368,7 +475,7 @@ class LiveStorage:
     def object_from_class_table(self, obj, klass):
         return self._schema_map[klass] is self._schema_map[obj.__class__]
 
-    def _get_query_bottom(self, table_name, where, joins):
+    def _get_query_bottom(self, table_name, where, joins, order_by, limit):
         sql = StringIO()
         sql.write("FROM %s\n" % table_name)
         if joins is not None:
@@ -376,20 +483,24 @@ class LiveStorage:
                 sql.write('LEFT JOIN %s ON %s\n' % (join_table, join_where))
         if where is not None:
             sql.write("WHERE %s" % where)
+        if order_by is not None:
+            sql.write(" ORDER BY %s" % order_by)
+        if limit is not None:
+            sql.write(" LIMIT %s" % limit)
         return sql.getvalue()
 
-    def query(self, klass, where, values=None, order_by=None, joins=None):
-        for id in self.query_ids(klass, where, values, order_by, joins):
+    def query(self, klass, where, values=None, order_by=None, joins=None,
+            limit=None):
+        for id in self.query_ids(klass, where, values, order_by, joins, limit):
             yield self._object_map[id]
 
-    def query_ids(self, klass, where, values=None, order_by=None, joins=None):
+    def query_ids(self, klass, where, values=None, order_by=None, joins=None,
+            limit=None):
         schema = self._schema_map[klass]
         sql = StringIO()
         sql.write("SELECT %s.id " % schema.table_name)
-        sql.write(self._get_query_bottom(schema.table_name, where, joins))
-        if order_by is not None:
-            sql.write(" ORDER BY %s" % order_by)
-
+        sql.write(self._get_query_bottom(schema.table_name, where, joins,
+            order_by, limit))
         self.cursor.execute(sql.getvalue(), values)
         rv = [row[0] for row in self.cursor.fetchall()]
         unrestored_ids = set(rv).difference(self._ids_loaded)
@@ -411,9 +522,7 @@ class LiveStorage:
         # we can only feed sqlite so many variables at once, send it chunks of
         # 900 ids at once
         id_list = tuple(id_set)
-        for start in xrange(0, len(id_list), 900):
-            id_list_chunk = id_list[start:start+900]
-
+        for id_list_chunk in split_values_for_sqlite(id_list):
             sql = StringIO()
             sql.write("SELECT %s " % (', '.join(column_names),))
             sql.write("FROM %s WHERE id IN (%s)" % (schema.table_name, 
@@ -462,11 +571,12 @@ class LiveStorage:
     def persistent_object_count(self):
         return len(self._object_map)
 
-    def query_count(self, klass, where, values=None, joins=None):
+    def query_count(self, klass, where, values=None, joins=None, limit=None):
         schema = self._schema_map[klass]
         sql = StringIO()
         sql.write('SELECT COUNT(*) ')
-        sql.write(self._get_query_bottom(schema.table_name, where, joins))
+        sql.write(self._get_query_bottom(schema.table_name, where, joins,
+            None, limit))
         return self._execute(sql.getvalue(), values)[0][0]
 
     def delete(self, klass, where, values):
@@ -477,45 +587,71 @@ class LiveStorage:
             sql.write('\nWHERE %s' % where)
         self._execute(sql.getvalue(), values, is_update=True)
 
-    def select(self, klass, columns, where, values):
+    def select(self, klass, columns, where, values, convert=True):
         schema = self._schema_map[klass]
         sql = StringIO()
-        sql.write('SELECT %s ' % columns)
-        sql.write(self._get_query_bottom(schema.table_name, where, None))
-        return self._execute(sql.getvalue(), values)
+        sql.write('SELECT %s ' % ', '.join(columns))
+        sql.write(self._get_query_bottom(schema.table_name, where, None, None,
+            None))
+        results = self._execute(sql.getvalue(), values)
+        if not convert:
+            return results
+        schema_items = [self._schema_column_map[schema, c] for c in columns]
+        rows = []
+        for row in results:
+            converted_row = []
+            for name, schema_item, value in itertools.izip(columns,
+                    schema_items, row):
+                converted_row.append(self._converter.from_sql(schema, name,
+                    schema_item, value))
+            rows.append(converted_row)
+        return rows
 
-    def _execute(self, sql, values, is_update=False):
+    def on_event_finished(self, eventloop, success):
+        self.finish_transaction(commit=success)
+
+    def finish_transaction(self, commit=True):
+        if len(self._statements_in_transaction) == 0:
+            return
+        if not self._quitting_from_operational_error:
+            if commit:
+                self.cursor.execute("COMMIT TRANSACTION")
+            else:
+                self.cursor.execute("ROLLBACK TRANSACTION")
+        self._statements_in_transaction = []
+
+    def _execute(self, sql, values, is_update=False, many=False):
         if is_update and self._quitting_from_operational_error:
             # We want to avoid updating the database at this point.
             return
 
+        if is_update and len(self._statements_in_transaction) == 0:
+            self.cursor.execute("BEGIN TRANSACTION")
+
         if values is None:
             values = ()
 
         failed = False
-        while True:
-            try:
-                self._time_execute(sql, values)
-            except sqlite3.OperationalError, e:
-                # printing the traceback here in whole rather than doing
-                # a logging.exception which seems to show the traceback
-                # up to the try/except handler.
-                logging.exception("OperationalError\n"
-                                  "statement: %s\n\n"
-                                  "values: %s\n\n"
-                                  "full stack:\n%s\n", sql, values,
-                                  "".join(traceback.format_stack()))
-                if not is_update and self._quitting_from_operational_error:
-                    # This is a very bad state to be in because code calling
-                    # us expects a return value.  I think the best we can do
-                    # is re-raise the exception (BDK)
-                    raise
-                failed = True
-                self._handle_operational_error(str(e))
-                if self._quitting_from_operational_error:
-                    break
+        if is_update:
+            self._statements_in_transaction.append((sql, values, many))
+        try:
+            self._time_execute(sql, values, many)
+        except sqlite3.OperationalError, e:
+            self._log_error(sql, values, many)
+            failed = True
+            if is_update:
+                self._current_select_statement = None
             else:
-                break
+                # Make sure we re-run our SELECT statement so that the call to
+                # fetchall() at the end of this method works. (#12885)
+                self._current_select_statement = (sql, values, many)
+            self._handle_operational_error(e)
+            if self._quitting_from_operational_error and not is_update:
+                # This is a very bad state to be in because code calling
+                # us expects a return value.  I think the best we can do
+                # is re-raise the exception (BDK)
+                raise
+
         if failed and not self._quitting_from_operational_error:
             title = _("%(appname)s database save succeeded",
                       {"appname": config.get(prefs.SHORT_APP_NAME)})
@@ -527,13 +663,59 @@ class LiveStorage:
         else:
             return self.cursor.fetchall()
 
-    def _time_execute(self, sql, values):
+    def _time_execute(self, sql, values, many):
         start = time.time()
-        self.cursor.execute(sql, values)
+        if many:
+            self.cursor.executemany(sql, values)
+        else:
+            self.cursor.execute(sql, values)
         end = time.time()
         self._check_time(sql, end-start)
 
-    def _handle_operational_error(self, error_text):
+    def _log_error(self, sql, values, many):
+            # printing the traceback here in whole rather than doing
+            # a logging.exception which seems to show the traceback
+            # up to the try/except handler.
+            logging.exception("OperationalError\n"
+                              "statement: %s\n\n"
+                              "values: %s\n\n"
+                              "many: %s\n\n"
+                              "full stack:\n%s\n", sql, values, many,
+                              "".join(traceback.format_stack()))
+
+    def _try_rerunning_transaction(self):
+        if self._statements_in_transaction:
+            # We may have only been trying to execute SELECT statements.  If
+            # that's true, don't start a transaction. (#12885)
+            self.cursor.execute("BEGIN TRANSACTION")
+        to_run = self._statements_in_transaction[:]
+        if self._current_select_statement:
+            to_run.append(self._current_select_statement)
+        for (sql, values, many) in to_run:
+            try:
+                self._time_execute(sql, values, many)
+            except sqlite3.OperationalError, e:
+                self._log_error(sql, values, many)
+                return False
+        return True
+
+    def _handle_operational_error(self, e):
+        if self._quitting_from_operational_error:
+            return
+        while True:
+            # try to rollback our old transaction if SQLite hasn't done it
+            # automatically
+            try:
+                self.cursor.execute("ROLLBACK TRANSACTION")
+            except sqlite3.OperationalError:
+                pass
+            self._show_save_error_dialog(str(e))
+            if self._quitting_from_operational_error:
+                return
+            if self._try_rerunning_transaction():
+                break
+
+    def _show_save_error_dialog(self, error_text):
         title = _("%(appname)s database save failed",
                   {"appname": config.get(prefs.SHORT_APP_NAME)})
         description = _(
@@ -595,6 +777,9 @@ class LiveStorage:
         self._create_variables_table()
         self._set_version()
 
+    def _get_version(self):
+        return self._get_variable(VERSION_KEY)
+
     def _set_version(self, version=None):
         """Set the database version to the current schema version."""
 
@@ -620,6 +805,8 @@ class LiveStorage:
         basic strategy is to log the error, save the current database then
         start fresh with an empty database.
         """
+        if self.raise_load_errors:
+            raise
         if util.chatter:
             logging.exception(message)
         self.connection.close()
@@ -629,16 +816,20 @@ class LiveStorage:
 
     def save_invalid_db(self):
         dir = os.path.dirname(self.path)
-        save_name = "corrupt_database"
+        save_name = self._find_unused_db_name("corrupt_database")
+        os.rename(self.path, os.path.join(dir, save_name))
+
+    def _find_unused_db_name(self, save_name):
+        dir = os.path.dirname(self.path)
+        org_save_name = save_name
         i = 0
         while os.path.exists(os.path.join(dir, save_name)):
             i += 1
-            save_name = "corrupt_database.%d" % i
-
-        os.rename(self.path, os.path.join(dir, save_name))
+            save_name = "%s.%d" % (org_save_name, i)
+        return save_name
 
     def dumpDatabase(self):
-        output = open (nextFreeFilename (os.path.join (config.get(prefs.SUPPORT_DIRECTORY), "database-dump.xml")), 'w')
+        output = open(next_free_filename(os.path.join(config.get(prefs.SUPPORT_DIRECTORY), "database-dump.xml")), 'w')
         def indent(level):
             output.write('    ' * level)
         def output_object(table_name, values):
