@@ -5,24 +5,23 @@ import time
 import unittest
 
 from miro import schema
-# much easier to type this way..
-from miro.schema import SchemaString, SchemaInt, SchemaFloat, SchemaBool
-from miro.schema import SchemaDateTime, SchemaList, SchemaDict, SchemaObject
-from miro.schema import SchemaReprContainer, ValidationError
+from miro.schema import (SchemaString, SchemaInt, SchemaFloat, SchemaBool,
+                         SchemaDateTime, SchemaList, SchemaDict, SchemaObject,
+                         SchemaReprContainer, ValidationError)
 from miro.test.framework import MiroTestCase
 
 class TestValidation(MiroTestCase):
-    def testModuleVariablesDefined(self):
+    def test_module_variables_defined(self):
         self.assert_(hasattr(schema, 'VERSION'))
         self.assert_(hasattr(schema, 'object_schemas'))
 
-    def testNoneValidation(self):
+    def test_none_validation(self):
         self.assertRaises(ValidationError, SchemaInt(noneOk=False).validate,
-                None)
+                          None)
         self.assertRaises(ValidationError, SchemaInt().validate, None)
         SchemaInt(noneOk=True).validate(None)
 
-    def testBoolValiation(self):
+    def test_bool_validation(self):
         schemabool = SchemaBool()
         self.assertRaises(ValidationError, schemabool.validate, 1)
         self.assertRaises(ValidationError, schemabool.validate, 0)
@@ -31,7 +30,7 @@ class TestValidation(MiroTestCase):
         schemabool.validate(True)
         schemabool.validate(False)
 
-    def testDateTimeValiation(self):
+    def test_date_time_validation(self):
         schemadatetime = SchemaDateTime()
         self.assertRaises(ValidationError, schemadatetime.validate, 1)
         self.assertRaises(ValidationError, schemadatetime.validate, 0)
@@ -39,37 +38,37 @@ class TestValidation(MiroTestCase):
         self.assertRaises(ValidationError, schemadatetime.validate, delta)
         schemadatetime.validate(datetime.datetime(1980, 8, 1))
 
-    def testIntValiation(self):
+    def test_int_validation(self):
         schemaint = SchemaInt()
         self.assertRaises(ValidationError, schemaint.validate, "One")
         self.assertRaises(ValidationError, schemaint.validate, 1.4)
         schemaint.validate(1)
         schemaint.validate(1L)
 
-    def testFloatValiation(self):
+    def test_float_validation(self):
         schemafloat = SchemaFloat()
         self.assertRaises(ValidationError, schemafloat.validate, "One half")
         self.assertRaises(ValidationError, schemafloat.validate, 1)
         schemafloat.validate(1.4)
 
-    def testStringValidation(self):
+    def test_string_validation(self):
         schemastring = SchemaString()
         self.assertRaises(ValidationError, schemastring.validate, 10123)
         self.assertRaises(ValidationError, schemastring.validate, "10123")
         schemastring.validate(u"10123")
 
-    def testReprContainerValidation(self):
+    def test_repr_container_validatoin(self):
         schemasimple = SchemaReprContainer()
         schemasimple.validate({1: u"Ben", u"pie": 3.1415})
         schemasimple.validate([1, 1, u"two", u"three", 5])
         schemasimple.validate({u'y2k': datetime.datetime(2000, 1, 1),
-                'now': time.localtime()})
+                               'now': time.localtime()})
         schemasimple.validate({
-                'fib': (1, 1, u"two", u"three", 5),
-                'square': (1, 4, u"nine", 16),
-                'fact': (1, 2.0, 6, u"twenty-four"),
+            'fib': (1, 1, u"two", u"three", 5),
+            'square': (1, 4, u"nine", 16),
+            'fact': (1, 2.0, 6, u"twenty-four"),
             })
-        #make sure circular references doesn't screw it up
+        # make sure circular references doesn't screw it up
         l = []
         d = {}
         l.extend([l, d])
@@ -80,25 +79,25 @@ class TestValidation(MiroTestCase):
         class TestObject(object):
             pass
         self.assertRaises(ValidationError, schemasimple.validate,
-                TestObject())
+                          TestObject())
         self.assertRaises(ValidationError, schemasimple.validate,
-                [TestObject()])
+                          [TestObject()])
         self.assertRaises(ValidationError, schemasimple.validate, 
-                {'object': TestObject()})
+                          {'object': TestObject()})
 
-    def testListValidation(self):
+    def test_list_validation(self):
         schemalist = SchemaList(SchemaInt())
         self.assertRaises(ValidationError, schemalist.validate,
-                1234)
+                          1234)
         schemalist.validate([1, 2, 3, 4])
 
-    def testDictValidation(self):
+    def test_dict_validation(self):
         schemadict = SchemaDict(SchemaInt(), SchemaString())
         self.assertRaises(ValidationError, schemadict.validate,
                 1234)
         schemadict.validate({12: u"Buckle my shoe"})
 
-    def testObjectValidation(self):
+    def test_object_validation(self):
         class TestObject(object):
             pass
         class ChildObject(TestObject):
