@@ -1,5 +1,5 @@
 # Miro - an RSS based video player application
-# Copyright (C) 2005-2009 Participatory Culture Foundation
+# Copyright (C) 2005-2010 Participatory Culture Foundation
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -39,24 +39,26 @@ import logging
 
 class XHTMLifier(HTMLParser):
     """Very simple parser to convert HTML to XHTML
+
     """
-    def convert(self, data, addTopTags=False, filterFontTags=False):
+    # FIXME - this should probably be rewritten to use StringIO.
+    def convert(self, data, add_top_tags=False, filter_font_tags=False):
         """Converts an HTML data unicode string to an XHTML data
         unicode string.
         """
         try:
-            if addTopTags:
+            if add_top_tags:
                 self.output = u'<html><head></head><body>'
             else:
                 self.output = ''
             self.stack = []
-            self.filterFontTags = filterFontTags
+            self.filter_font_tags = filter_font_tags
             self.feed(data)
             self.close()
             while len(self.stack) > 0:
                 temp = self.stack.pop()
                 self.output += u'</'+temp+'>'
-            if addTopTags:
+            if add_top_tags:
                 self.output += u'</body></html>'
             return self.output
 
@@ -67,28 +69,36 @@ class XHTMLifier(HTMLParser):
     def handle_starttag(self, tag, attrs):
         if tag.lower() == 'br':
             self.output += u'<br/>'
-        else:
-            if not (tag.lower() == 'font' and self.filterFontTags):
-                self.output += u'<'+tag
-                for attr in attrs:
-                    if attr[1] == None:
-                        self.output += u' '+attr[0]+u'='+xml.sax.saxutils.quoteattr(attr[0])
-                    else:
-                        self.output += u' '+attr[0]+u'='+xml.sax.saxutils.quoteattr(attr[1])
-                self.output += u'>'
-            self.stack.append(tag)
+            return
+
+
+        if not (tag.lower() == 'font' and self.filter_font_tags):
+            self.output += u'<' + tag
+            for attr in attrs:
+                if attr[1] == None:
+                    self.output += (u' ' +
+                                    attr[0] +
+                                    u'=' +
+                                    xml.sax.saxutils.quoteattr(attr[0]))
+                else:
+                    self.output += (u' ' +
+                                    attr[0] +
+                                    u'=' +
+                                    xml.sax.saxutils.quoteattr(attr[1]))
+            self.output += u'>'
+        self.stack.append(tag)
 
     def handle_endtag(self, tag):
         if tag.lower() != 'br' and len(self.stack) > 1:
             temp = self.stack.pop()
-            if not (tag.lower() == 'font' and self.filterFontTags):
+            if not (tag.lower() == 'font' and self.filter_font_tags):
                 self.output += u'</'+temp+u'>'
                 while temp != tag and len(self.stack) > 1:
                     temp = self.stack.pop()
-                    self.output += u'</'+temp+u'>'
+                    self.output += u'</' + temp + u'>'
 
     def handle_startendtag(self, tag, attrs):
-        self.output += u'<'+tag+u'/>'
+        self.output += u'<' + tag + u'/>'
 
     def handle_data(self, data):
         data = data.replace(u'&', u'&amp;')
@@ -96,10 +106,10 @@ class XHTMLifier(HTMLParser):
         self.output += data
 
     def handle_charref(self, name):
-        self.output += u'&#'+name+';'
+        self.output += u'&#' + name + ';'
 
     def handle_entityref(self, name):
-        self.output += u'&'+name+';'
+        self.output += u'&' + name + ';'
 
 def unescape(data):
     """Parses HTML entities in data"""
@@ -117,36 +127,37 @@ def urldecode(data):
     """Gets a string from a URL"""
     return unquote(data)
 
-def xhtmlify(data, addTopTags=False, filterFontTags=False):
+def xhtmlify(data, add_top_tags=False, filter_font_tags=False):
     """Returns XHTMLified version of HTML document"""
     x = XHTMLifier()
-    ret = x.convert(data, addTopTags, filterFontTags)
+    ret = x.convert(data, add_top_tags, filter_font_tags)
 
     # if we got a bad return, try it again without filtering font
     # tags
-    if ret is None and filterFontTags:
+    if ret is None and filter_font_tags:
         x = XHTMLifier()
-        ret = x.convert(data, addTopTags, filterFontTags=False)
+        ret = x.convert(data, add_top_tags, filter_font_tags=False)
 
-    # if that's still bad, try converting &quot; to "
-    # this fixes bug #10095 where Google Video items are sometimes half
-    # quoted.
+    # if that's still bad, try converting &quot; to ".
+    # this fixes bug #10095 where Google Video items are sometimes
+    # half quoted.
     if ret is None:
         x = XHTMLifier()
-        ret = x.convert(data.replace("&quot;", '"'), addTopTags, filterFontTags=False)
+        ret = x.convert(data.replace("&quot;", '"'), add_top_tags,
+                        filter_font_tags=False)
 
     if ret is None:
         ret = u""
 
     return ret
 
-_xml_header_re = re.compile("^\<\?xml\s*(.*?)\s*\?\>(.*)", re.S)
+XML_HEADER_RE = re.compile("^\<\?xml\s*(.*?)\s*\?\>(.*)", re.S)
 
 def fix_xml_header(data, charset):
     """Adds a <?xml ?> header to the given xml data or replaces an
     existing one without a charset with one that has a charset
     """
-    header = _xml_header_re.match(data)
+    header = XML_HEADER_RE.match(data)
     if header is None:
         # print "Adding header %s" % charset
         return '<?xml version="1.0" encoding="%s"?>%s' % (charset, data)
@@ -160,7 +171,8 @@ def fix_xml_header(data, charset):
     return '<?xml %s encoding="%s"?>%s' % (xml_decl, charset, the_rest)
 
 
-_html_header_re = re.compile(u"^(.*)\<\s*head\s*(.*?)\s*\>(.*?)\</\s*head\s*\>(.*)", re.I | re.S)
+HTML_HEADER_RE = re.compile(
+    u"^(.*)\<\s*head\s*(.*?)\s*\>(.*?)\</\s*head\s*\>(.*)", re.I | re.S)
 
 def fix_html_header(data, charset):
     """Adds a <meta http-equiv="Content-Type" content="text/html;
@@ -169,7 +181,7 @@ def fix_html_header(data, charset):
     Since we're only feeding this to our own HTML Parser anyway, we
     don't care that it might bung up XHTML.
     """
-    header = _html_header_re.match(data)
+    header = HTML_HEADER_RE.match(data)
     if header is None:
         # something is very wrong with this HTML
         return data
@@ -179,11 +191,11 @@ def fix_html_header(data, charset):
     if head_tags.lower().find('content-type') != -1:
         return data
 
-    #print " adding %s Content-Type to HTML" % charset
     return header.expand('\\1<head\\2><meta http-equiv="Content-Type" content="text/html; charset=') + charset + header.expand('">\\3</head>\\4')
 
 def url_encode_dict(orig):
-    """Converts a Python dictionary to data suitable for a POST or GET submission
+    """Converts a Python dictionary to data suitable for a POST or GET
+    submission
     """
     output = []
     for key, val in orig.items():
@@ -196,12 +208,12 @@ def url_encode_dict(orig):
             logging.warning("url_encode_dict: trying to encode non-string: '%s'", repr(val))
     return '&'.join(output)
 
-def multipart_encode(postVars, files):
+def multipart_encode(post_vars, files):
     # Generate a random 64bit number for our boundaries
-    boundary = 'dp%s'% hex(random.getrandbits(64))[2:-1]
+    boundary = 'dp%s' % hex(random.getrandbits(64))[2:-1]
     output = []
-    if postVars is not None:
-        for key, value in postVars.items():
+    if post_vars is not None:
+        for key, value in post_vars.items():
             output.append('--%s\r\n' % boundary)
             output.append('Content-Disposition: form-data; name="%s"\r\n\r\n' %
                           quote_plus(key))
@@ -216,7 +228,7 @@ def multipart_encode(postVars, files):
                           (quote_plus(key),
                            quote_plus(files[key]['filename'])))
             output.append('Content-Type: %s\r\n\r\n' % files[key]['mimetype'])
-            
+
             output.append(files[key]['handle'].read())
             output.append('\r\n')
             files[key]['handle'].close()
